# Copyright 2016 Game Server Services, Inc. or its affiliates. All Rights
# Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License").
# You may not use this file except in compliance with the License.
# A copy of the License is located at
#
#  http://www.apache.org/licenses/LICENSE-2.0
#
# or in the "license" file accompanying this file. This file is distributed
# on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
# express or implied. See the License for the specific language governing
# permissions and limitations under the License.

from __future__ import annotations

from .model import *


class DescribeNamespacesResult(core.Gs2Result):
    items: List[Namespace] = None
    next_page_token: str = None

    def with_items(self, items: List[Namespace]) -> DescribeNamespacesResult:
        self.items = items
        return self

    def with_next_page_token(self, next_page_token: str) -> DescribeNamespacesResult:
        self.next_page_token = next_page_token
        return self

    def get(self, key, default=None):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return default

    def __getitem__(self, key):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return None

    @staticmethod
    def from_dict(
        data: Dict[str, Any],
    ) -> Optional[DescribeNamespacesResult]:
        if data is None:
            return None
        return DescribeNamespacesResult()\
            .with_items([
                Namespace.from_dict(data.get('items')[i])
                for i in range(len(data.get('items')) if data.get('items') else 0)
            ])\
            .with_next_page_token(data.get('nextPageToken'))

    def to_dict(self) -> Dict[str, Any]:
        return {
            "items": [
                self.items[i].to_dict() if self.items[i] else None
                for i in range(len(self.items) if self.items else 0)
            ],
            "nextPageToken": self.next_page_token,
        }


class CreateNamespaceResult(core.Gs2Result):
    item: Namespace = None

    def with_item(self, item: Namespace) -> CreateNamespaceResult:
        self.item = item
        return self

    def get(self, key, default=None):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return default

    def __getitem__(self, key):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return None

    @staticmethod
    def from_dict(
        data: Dict[str, Any],
    ) -> Optional[CreateNamespaceResult]:
        if data is None:
            return None
        return CreateNamespaceResult()\
            .with_item(Namespace.from_dict(data.get('item')))

    def to_dict(self) -> Dict[str, Any]:
        return {
            "item": self.item.to_dict() if self.item else None,
        }


class GetNamespaceStatusResult(core.Gs2Result):
    status: str = None

    def with_status(self, status: str) -> GetNamespaceStatusResult:
        self.status = status
        return self

    def get(self, key, default=None):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return default

    def __getitem__(self, key):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return None

    @staticmethod
    def from_dict(
        data: Dict[str, Any],
    ) -> Optional[GetNamespaceStatusResult]:
        if data is None:
            return None
        return GetNamespaceStatusResult()\
            .with_status(data.get('status'))

    def to_dict(self) -> Dict[str, Any]:
        return {
            "status": self.status,
        }


class GetNamespaceResult(core.Gs2Result):
    item: Namespace = None

    def with_item(self, item: Namespace) -> GetNamespaceResult:
        self.item = item
        return self

    def get(self, key, default=None):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return default

    def __getitem__(self, key):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return None

    @staticmethod
    def from_dict(
        data: Dict[str, Any],
    ) -> Optional[GetNamespaceResult]:
        if data is None:
            return None
        return GetNamespaceResult()\
            .with_item(Namespace.from_dict(data.get('item')))

    def to_dict(self) -> Dict[str, Any]:
        return {
            "item": self.item.to_dict() if self.item else None,
        }


class UpdateNamespaceResult(core.Gs2Result):
    item: Namespace = None

    def with_item(self, item: Namespace) -> UpdateNamespaceResult:
        self.item = item
        return self

    def get(self, key, default=None):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return default

    def __getitem__(self, key):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return None

    @staticmethod
    def from_dict(
        data: Dict[str, Any],
    ) -> Optional[UpdateNamespaceResult]:
        if data is None:
            return None
        return UpdateNamespaceResult()\
            .with_item(Namespace.from_dict(data.get('item')))

    def to_dict(self) -> Dict[str, Any]:
        return {
            "item": self.item.to_dict() if self.item else None,
        }


class DeleteNamespaceResult(core.Gs2Result):
    item: Namespace = None

    def with_item(self, item: Namespace) -> DeleteNamespaceResult:
        self.item = item
        return self

    def get(self, key, default=None):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return default

    def __getitem__(self, key):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return None

    @staticmethod
    def from_dict(
        data: Dict[str, Any],
    ) -> Optional[DeleteNamespaceResult]:
        if data is None:
            return None
        return DeleteNamespaceResult()\
            .with_item(Namespace.from_dict(data.get('item')))

    def to_dict(self) -> Dict[str, Any]:
        return {
            "item": self.item.to_dict() if self.item else None,
        }


class DescribeInventoryModelMastersResult(core.Gs2Result):
    items: List[InventoryModelMaster] = None
    next_page_token: str = None

    def with_items(self, items: List[InventoryModelMaster]) -> DescribeInventoryModelMastersResult:
        self.items = items
        return self

    def with_next_page_token(self, next_page_token: str) -> DescribeInventoryModelMastersResult:
        self.next_page_token = next_page_token
        return self

    def get(self, key, default=None):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return default

    def __getitem__(self, key):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return None

    @staticmethod
    def from_dict(
        data: Dict[str, Any],
    ) -> Optional[DescribeInventoryModelMastersResult]:
        if data is None:
            return None
        return DescribeInventoryModelMastersResult()\
            .with_items([
                InventoryModelMaster.from_dict(data.get('items')[i])
                for i in range(len(data.get('items')) if data.get('items') else 0)
            ])\
            .with_next_page_token(data.get('nextPageToken'))

    def to_dict(self) -> Dict[str, Any]:
        return {
            "items": [
                self.items[i].to_dict() if self.items[i] else None
                for i in range(len(self.items) if self.items else 0)
            ],
            "nextPageToken": self.next_page_token,
        }


class CreateInventoryModelMasterResult(core.Gs2Result):
    item: InventoryModelMaster = None

    def with_item(self, item: InventoryModelMaster) -> CreateInventoryModelMasterResult:
        self.item = item
        return self

    def get(self, key, default=None):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return default

    def __getitem__(self, key):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return None

    @staticmethod
    def from_dict(
        data: Dict[str, Any],
    ) -> Optional[CreateInventoryModelMasterResult]:
        if data is None:
            return None
        return CreateInventoryModelMasterResult()\
            .with_item(InventoryModelMaster.from_dict(data.get('item')))

    def to_dict(self) -> Dict[str, Any]:
        return {
            "item": self.item.to_dict() if self.item else None,
        }


class GetInventoryModelMasterResult(core.Gs2Result):
    item: InventoryModelMaster = None

    def with_item(self, item: InventoryModelMaster) -> GetInventoryModelMasterResult:
        self.item = item
        return self

    def get(self, key, default=None):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return default

    def __getitem__(self, key):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return None

    @staticmethod
    def from_dict(
        data: Dict[str, Any],
    ) -> Optional[GetInventoryModelMasterResult]:
        if data is None:
            return None
        return GetInventoryModelMasterResult()\
            .with_item(InventoryModelMaster.from_dict(data.get('item')))

    def to_dict(self) -> Dict[str, Any]:
        return {
            "item": self.item.to_dict() if self.item else None,
        }


class UpdateInventoryModelMasterResult(core.Gs2Result):
    item: InventoryModelMaster = None

    def with_item(self, item: InventoryModelMaster) -> UpdateInventoryModelMasterResult:
        self.item = item
        return self

    def get(self, key, default=None):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return default

    def __getitem__(self, key):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return None

    @staticmethod
    def from_dict(
        data: Dict[str, Any],
    ) -> Optional[UpdateInventoryModelMasterResult]:
        if data is None:
            return None
        return UpdateInventoryModelMasterResult()\
            .with_item(InventoryModelMaster.from_dict(data.get('item')))

    def to_dict(self) -> Dict[str, Any]:
        return {
            "item": self.item.to_dict() if self.item else None,
        }


class DeleteInventoryModelMasterResult(core.Gs2Result):
    item: InventoryModelMaster = None

    def with_item(self, item: InventoryModelMaster) -> DeleteInventoryModelMasterResult:
        self.item = item
        return self

    def get(self, key, default=None):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return default

    def __getitem__(self, key):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return None

    @staticmethod
    def from_dict(
        data: Dict[str, Any],
    ) -> Optional[DeleteInventoryModelMasterResult]:
        if data is None:
            return None
        return DeleteInventoryModelMasterResult()\
            .with_item(InventoryModelMaster.from_dict(data.get('item')))

    def to_dict(self) -> Dict[str, Any]:
        return {
            "item": self.item.to_dict() if self.item else None,
        }


class DescribeInventoryModelsResult(core.Gs2Result):
    items: List[InventoryModel] = None

    def with_items(self, items: List[InventoryModel]) -> DescribeInventoryModelsResult:
        self.items = items
        return self

    def get(self, key, default=None):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return default

    def __getitem__(self, key):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return None

    @staticmethod
    def from_dict(
        data: Dict[str, Any],
    ) -> Optional[DescribeInventoryModelsResult]:
        if data is None:
            return None
        return DescribeInventoryModelsResult()\
            .with_items([
                InventoryModel.from_dict(data.get('items')[i])
                for i in range(len(data.get('items')) if data.get('items') else 0)
            ])

    def to_dict(self) -> Dict[str, Any]:
        return {
            "items": [
                self.items[i].to_dict() if self.items[i] else None
                for i in range(len(self.items) if self.items else 0)
            ],
        }


class GetInventoryModelResult(core.Gs2Result):
    item: InventoryModel = None

    def with_item(self, item: InventoryModel) -> GetInventoryModelResult:
        self.item = item
        return self

    def get(self, key, default=None):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return default

    def __getitem__(self, key):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return None

    @staticmethod
    def from_dict(
        data: Dict[str, Any],
    ) -> Optional[GetInventoryModelResult]:
        if data is None:
            return None
        return GetInventoryModelResult()\
            .with_item(InventoryModel.from_dict(data.get('item')))

    def to_dict(self) -> Dict[str, Any]:
        return {
            "item": self.item.to_dict() if self.item else None,
        }


class DescribeItemModelMastersResult(core.Gs2Result):
    items: List[ItemModelMaster] = None
    next_page_token: str = None

    def with_items(self, items: List[ItemModelMaster]) -> DescribeItemModelMastersResult:
        self.items = items
        return self

    def with_next_page_token(self, next_page_token: str) -> DescribeItemModelMastersResult:
        self.next_page_token = next_page_token
        return self

    def get(self, key, default=None):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return default

    def __getitem__(self, key):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return None

    @staticmethod
    def from_dict(
        data: Dict[str, Any],
    ) -> Optional[DescribeItemModelMastersResult]:
        if data is None:
            return None
        return DescribeItemModelMastersResult()\
            .with_items([
                ItemModelMaster.from_dict(data.get('items')[i])
                for i in range(len(data.get('items')) if data.get('items') else 0)
            ])\
            .with_next_page_token(data.get('nextPageToken'))

    def to_dict(self) -> Dict[str, Any]:
        return {
            "items": [
                self.items[i].to_dict() if self.items[i] else None
                for i in range(len(self.items) if self.items else 0)
            ],
            "nextPageToken": self.next_page_token,
        }


class CreateItemModelMasterResult(core.Gs2Result):
    item: ItemModelMaster = None

    def with_item(self, item: ItemModelMaster) -> CreateItemModelMasterResult:
        self.item = item
        return self

    def get(self, key, default=None):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return default

    def __getitem__(self, key):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return None

    @staticmethod
    def from_dict(
        data: Dict[str, Any],
    ) -> Optional[CreateItemModelMasterResult]:
        if data is None:
            return None
        return CreateItemModelMasterResult()\
            .with_item(ItemModelMaster.from_dict(data.get('item')))

    def to_dict(self) -> Dict[str, Any]:
        return {
            "item": self.item.to_dict() if self.item else None,
        }


class GetItemModelMasterResult(core.Gs2Result):
    item: ItemModelMaster = None

    def with_item(self, item: ItemModelMaster) -> GetItemModelMasterResult:
        self.item = item
        return self

    def get(self, key, default=None):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return default

    def __getitem__(self, key):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return None

    @staticmethod
    def from_dict(
        data: Dict[str, Any],
    ) -> Optional[GetItemModelMasterResult]:
        if data is None:
            return None
        return GetItemModelMasterResult()\
            .with_item(ItemModelMaster.from_dict(data.get('item')))

    def to_dict(self) -> Dict[str, Any]:
        return {
            "item": self.item.to_dict() if self.item else None,
        }


class UpdateItemModelMasterResult(core.Gs2Result):
    item: ItemModelMaster = None

    def with_item(self, item: ItemModelMaster) -> UpdateItemModelMasterResult:
        self.item = item
        return self

    def get(self, key, default=None):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return default

    def __getitem__(self, key):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return None

    @staticmethod
    def from_dict(
        data: Dict[str, Any],
    ) -> Optional[UpdateItemModelMasterResult]:
        if data is None:
            return None
        return UpdateItemModelMasterResult()\
            .with_item(ItemModelMaster.from_dict(data.get('item')))

    def to_dict(self) -> Dict[str, Any]:
        return {
            "item": self.item.to_dict() if self.item else None,
        }


class DeleteItemModelMasterResult(core.Gs2Result):
    item: ItemModelMaster = None

    def with_item(self, item: ItemModelMaster) -> DeleteItemModelMasterResult:
        self.item = item
        return self

    def get(self, key, default=None):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return default

    def __getitem__(self, key):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return None

    @staticmethod
    def from_dict(
        data: Dict[str, Any],
    ) -> Optional[DeleteItemModelMasterResult]:
        if data is None:
            return None
        return DeleteItemModelMasterResult()\
            .with_item(ItemModelMaster.from_dict(data.get('item')))

    def to_dict(self) -> Dict[str, Any]:
        return {
            "item": self.item.to_dict() if self.item else None,
        }


class DescribeItemModelsResult(core.Gs2Result):
    items: List[ItemModel] = None

    def with_items(self, items: List[ItemModel]) -> DescribeItemModelsResult:
        self.items = items
        return self

    def get(self, key, default=None):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return default

    def __getitem__(self, key):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return None

    @staticmethod
    def from_dict(
        data: Dict[str, Any],
    ) -> Optional[DescribeItemModelsResult]:
        if data is None:
            return None
        return DescribeItemModelsResult()\
            .with_items([
                ItemModel.from_dict(data.get('items')[i])
                for i in range(len(data.get('items')) if data.get('items') else 0)
            ])

    def to_dict(self) -> Dict[str, Any]:
        return {
            "items": [
                self.items[i].to_dict() if self.items[i] else None
                for i in range(len(self.items) if self.items else 0)
            ],
        }


class GetItemModelResult(core.Gs2Result):
    item: ItemModel = None

    def with_item(self, item: ItemModel) -> GetItemModelResult:
        self.item = item
        return self

    def get(self, key, default=None):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return default

    def __getitem__(self, key):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return None

    @staticmethod
    def from_dict(
        data: Dict[str, Any],
    ) -> Optional[GetItemModelResult]:
        if data is None:
            return None
        return GetItemModelResult()\
            .with_item(ItemModel.from_dict(data.get('item')))

    def to_dict(self) -> Dict[str, Any]:
        return {
            "item": self.item.to_dict() if self.item else None,
        }


class DescribeSimpleInventoryModelMastersResult(core.Gs2Result):
    items: List[SimpleInventoryModelMaster] = None
    next_page_token: str = None

    def with_items(self, items: List[SimpleInventoryModelMaster]) -> DescribeSimpleInventoryModelMastersResult:
        self.items = items
        return self

    def with_next_page_token(self, next_page_token: str) -> DescribeSimpleInventoryModelMastersResult:
        self.next_page_token = next_page_token
        return self

    def get(self, key, default=None):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return default

    def __getitem__(self, key):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return None

    @staticmethod
    def from_dict(
        data: Dict[str, Any],
    ) -> Optional[DescribeSimpleInventoryModelMastersResult]:
        if data is None:
            return None
        return DescribeSimpleInventoryModelMastersResult()\
            .with_items([
                SimpleInventoryModelMaster.from_dict(data.get('items')[i])
                for i in range(len(data.get('items')) if data.get('items') else 0)
            ])\
            .with_next_page_token(data.get('nextPageToken'))

    def to_dict(self) -> Dict[str, Any]:
        return {
            "items": [
                self.items[i].to_dict() if self.items[i] else None
                for i in range(len(self.items) if self.items else 0)
            ],
            "nextPageToken": self.next_page_token,
        }


class CreateSimpleInventoryModelMasterResult(core.Gs2Result):
    item: SimpleInventoryModelMaster = None

    def with_item(self, item: SimpleInventoryModelMaster) -> CreateSimpleInventoryModelMasterResult:
        self.item = item
        return self

    def get(self, key, default=None):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return default

    def __getitem__(self, key):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return None

    @staticmethod
    def from_dict(
        data: Dict[str, Any],
    ) -> Optional[CreateSimpleInventoryModelMasterResult]:
        if data is None:
            return None
        return CreateSimpleInventoryModelMasterResult()\
            .with_item(SimpleInventoryModelMaster.from_dict(data.get('item')))

    def to_dict(self) -> Dict[str, Any]:
        return {
            "item": self.item.to_dict() if self.item else None,
        }


class GetSimpleInventoryModelMasterResult(core.Gs2Result):
    item: SimpleInventoryModelMaster = None

    def with_item(self, item: SimpleInventoryModelMaster) -> GetSimpleInventoryModelMasterResult:
        self.item = item
        return self

    def get(self, key, default=None):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return default

    def __getitem__(self, key):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return None

    @staticmethod
    def from_dict(
        data: Dict[str, Any],
    ) -> Optional[GetSimpleInventoryModelMasterResult]:
        if data is None:
            return None
        return GetSimpleInventoryModelMasterResult()\
            .with_item(SimpleInventoryModelMaster.from_dict(data.get('item')))

    def to_dict(self) -> Dict[str, Any]:
        return {
            "item": self.item.to_dict() if self.item else None,
        }


class UpdateSimpleInventoryModelMasterResult(core.Gs2Result):
    item: SimpleInventoryModelMaster = None

    def with_item(self, item: SimpleInventoryModelMaster) -> UpdateSimpleInventoryModelMasterResult:
        self.item = item
        return self

    def get(self, key, default=None):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return default

    def __getitem__(self, key):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return None

    @staticmethod
    def from_dict(
        data: Dict[str, Any],
    ) -> Optional[UpdateSimpleInventoryModelMasterResult]:
        if data is None:
            return None
        return UpdateSimpleInventoryModelMasterResult()\
            .with_item(SimpleInventoryModelMaster.from_dict(data.get('item')))

    def to_dict(self) -> Dict[str, Any]:
        return {
            "item": self.item.to_dict() if self.item else None,
        }


class DeleteSimpleInventoryModelMasterResult(core.Gs2Result):
    item: SimpleInventoryModelMaster = None

    def with_item(self, item: SimpleInventoryModelMaster) -> DeleteSimpleInventoryModelMasterResult:
        self.item = item
        return self

    def get(self, key, default=None):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return default

    def __getitem__(self, key):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return None

    @staticmethod
    def from_dict(
        data: Dict[str, Any],
    ) -> Optional[DeleteSimpleInventoryModelMasterResult]:
        if data is None:
            return None
        return DeleteSimpleInventoryModelMasterResult()\
            .with_item(SimpleInventoryModelMaster.from_dict(data.get('item')))

    def to_dict(self) -> Dict[str, Any]:
        return {
            "item": self.item.to_dict() if self.item else None,
        }


class DescribeSimpleInventoryModelsResult(core.Gs2Result):
    items: List[SimpleInventoryModel] = None

    def with_items(self, items: List[SimpleInventoryModel]) -> DescribeSimpleInventoryModelsResult:
        self.items = items
        return self

    def get(self, key, default=None):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return default

    def __getitem__(self, key):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return None

    @staticmethod
    def from_dict(
        data: Dict[str, Any],
    ) -> Optional[DescribeSimpleInventoryModelsResult]:
        if data is None:
            return None
        return DescribeSimpleInventoryModelsResult()\
            .with_items([
                SimpleInventoryModel.from_dict(data.get('items')[i])
                for i in range(len(data.get('items')) if data.get('items') else 0)
            ])

    def to_dict(self) -> Dict[str, Any]:
        return {
            "items": [
                self.items[i].to_dict() if self.items[i] else None
                for i in range(len(self.items) if self.items else 0)
            ],
        }


class GetSimpleInventoryModelResult(core.Gs2Result):
    item: SimpleInventoryModel = None

    def with_item(self, item: SimpleInventoryModel) -> GetSimpleInventoryModelResult:
        self.item = item
        return self

    def get(self, key, default=None):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return default

    def __getitem__(self, key):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return None

    @staticmethod
    def from_dict(
        data: Dict[str, Any],
    ) -> Optional[GetSimpleInventoryModelResult]:
        if data is None:
            return None
        return GetSimpleInventoryModelResult()\
            .with_item(SimpleInventoryModel.from_dict(data.get('item')))

    def to_dict(self) -> Dict[str, Any]:
        return {
            "item": self.item.to_dict() if self.item else None,
        }


class DescribeSimpleItemModelMastersResult(core.Gs2Result):
    items: List[SimpleItemModelMaster] = None
    next_page_token: str = None

    def with_items(self, items: List[SimpleItemModelMaster]) -> DescribeSimpleItemModelMastersResult:
        self.items = items
        return self

    def with_next_page_token(self, next_page_token: str) -> DescribeSimpleItemModelMastersResult:
        self.next_page_token = next_page_token
        return self

    def get(self, key, default=None):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return default

    def __getitem__(self, key):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return None

    @staticmethod
    def from_dict(
        data: Dict[str, Any],
    ) -> Optional[DescribeSimpleItemModelMastersResult]:
        if data is None:
            return None
        return DescribeSimpleItemModelMastersResult()\
            .with_items([
                SimpleItemModelMaster.from_dict(data.get('items')[i])
                for i in range(len(data.get('items')) if data.get('items') else 0)
            ])\
            .with_next_page_token(data.get('nextPageToken'))

    def to_dict(self) -> Dict[str, Any]:
        return {
            "items": [
                self.items[i].to_dict() if self.items[i] else None
                for i in range(len(self.items) if self.items else 0)
            ],
            "nextPageToken": self.next_page_token,
        }


class CreateSimpleItemModelMasterResult(core.Gs2Result):
    item: SimpleItemModelMaster = None

    def with_item(self, item: SimpleItemModelMaster) -> CreateSimpleItemModelMasterResult:
        self.item = item
        return self

    def get(self, key, default=None):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return default

    def __getitem__(self, key):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return None

    @staticmethod
    def from_dict(
        data: Dict[str, Any],
    ) -> Optional[CreateSimpleItemModelMasterResult]:
        if data is None:
            return None
        return CreateSimpleItemModelMasterResult()\
            .with_item(SimpleItemModelMaster.from_dict(data.get('item')))

    def to_dict(self) -> Dict[str, Any]:
        return {
            "item": self.item.to_dict() if self.item else None,
        }


class GetSimpleItemModelMasterResult(core.Gs2Result):
    item: SimpleItemModelMaster = None

    def with_item(self, item: SimpleItemModelMaster) -> GetSimpleItemModelMasterResult:
        self.item = item
        return self

    def get(self, key, default=None):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return default

    def __getitem__(self, key):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return None

    @staticmethod
    def from_dict(
        data: Dict[str, Any],
    ) -> Optional[GetSimpleItemModelMasterResult]:
        if data is None:
            return None
        return GetSimpleItemModelMasterResult()\
            .with_item(SimpleItemModelMaster.from_dict(data.get('item')))

    def to_dict(self) -> Dict[str, Any]:
        return {
            "item": self.item.to_dict() if self.item else None,
        }


class UpdateSimpleItemModelMasterResult(core.Gs2Result):
    item: SimpleItemModelMaster = None

    def with_item(self, item: SimpleItemModelMaster) -> UpdateSimpleItemModelMasterResult:
        self.item = item
        return self

    def get(self, key, default=None):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return default

    def __getitem__(self, key):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return None

    @staticmethod
    def from_dict(
        data: Dict[str, Any],
    ) -> Optional[UpdateSimpleItemModelMasterResult]:
        if data is None:
            return None
        return UpdateSimpleItemModelMasterResult()\
            .with_item(SimpleItemModelMaster.from_dict(data.get('item')))

    def to_dict(self) -> Dict[str, Any]:
        return {
            "item": self.item.to_dict() if self.item else None,
        }


class DeleteSimpleItemModelMasterResult(core.Gs2Result):
    item: SimpleItemModelMaster = None

    def with_item(self, item: SimpleItemModelMaster) -> DeleteSimpleItemModelMasterResult:
        self.item = item
        return self

    def get(self, key, default=None):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return default

    def __getitem__(self, key):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return None

    @staticmethod
    def from_dict(
        data: Dict[str, Any],
    ) -> Optional[DeleteSimpleItemModelMasterResult]:
        if data is None:
            return None
        return DeleteSimpleItemModelMasterResult()\
            .with_item(SimpleItemModelMaster.from_dict(data.get('item')))

    def to_dict(self) -> Dict[str, Any]:
        return {
            "item": self.item.to_dict() if self.item else None,
        }


class DescribeSimpleItemModelsResult(core.Gs2Result):
    items: List[SimpleItemModel] = None

    def with_items(self, items: List[SimpleItemModel]) -> DescribeSimpleItemModelsResult:
        self.items = items
        return self

    def get(self, key, default=None):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return default

    def __getitem__(self, key):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return None

    @staticmethod
    def from_dict(
        data: Dict[str, Any],
    ) -> Optional[DescribeSimpleItemModelsResult]:
        if data is None:
            return None
        return DescribeSimpleItemModelsResult()\
            .with_items([
                SimpleItemModel.from_dict(data.get('items')[i])
                for i in range(len(data.get('items')) if data.get('items') else 0)
            ])

    def to_dict(self) -> Dict[str, Any]:
        return {
            "items": [
                self.items[i].to_dict() if self.items[i] else None
                for i in range(len(self.items) if self.items else 0)
            ],
        }


class GetSimpleItemModelResult(core.Gs2Result):
    item: SimpleItemModel = None

    def with_item(self, item: SimpleItemModel) -> GetSimpleItemModelResult:
        self.item = item
        return self

    def get(self, key, default=None):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return default

    def __getitem__(self, key):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return None

    @staticmethod
    def from_dict(
        data: Dict[str, Any],
    ) -> Optional[GetSimpleItemModelResult]:
        if data is None:
            return None
        return GetSimpleItemModelResult()\
            .with_item(SimpleItemModel.from_dict(data.get('item')))

    def to_dict(self) -> Dict[str, Any]:
        return {
            "item": self.item.to_dict() if self.item else None,
        }


class ExportMasterResult(core.Gs2Result):
    item: CurrentItemModelMaster = None

    def with_item(self, item: CurrentItemModelMaster) -> ExportMasterResult:
        self.item = item
        return self

    def get(self, key, default=None):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return default

    def __getitem__(self, key):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return None

    @staticmethod
    def from_dict(
        data: Dict[str, Any],
    ) -> Optional[ExportMasterResult]:
        if data is None:
            return None
        return ExportMasterResult()\
            .with_item(CurrentItemModelMaster.from_dict(data.get('item')))

    def to_dict(self) -> Dict[str, Any]:
        return {
            "item": self.item.to_dict() if self.item else None,
        }


class GetCurrentItemModelMasterResult(core.Gs2Result):
    item: CurrentItemModelMaster = None

    def with_item(self, item: CurrentItemModelMaster) -> GetCurrentItemModelMasterResult:
        self.item = item
        return self

    def get(self, key, default=None):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return default

    def __getitem__(self, key):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return None

    @staticmethod
    def from_dict(
        data: Dict[str, Any],
    ) -> Optional[GetCurrentItemModelMasterResult]:
        if data is None:
            return None
        return GetCurrentItemModelMasterResult()\
            .with_item(CurrentItemModelMaster.from_dict(data.get('item')))

    def to_dict(self) -> Dict[str, Any]:
        return {
            "item": self.item.to_dict() if self.item else None,
        }


class UpdateCurrentItemModelMasterResult(core.Gs2Result):
    item: CurrentItemModelMaster = None

    def with_item(self, item: CurrentItemModelMaster) -> UpdateCurrentItemModelMasterResult:
        self.item = item
        return self

    def get(self, key, default=None):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return default

    def __getitem__(self, key):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return None

    @staticmethod
    def from_dict(
        data: Dict[str, Any],
    ) -> Optional[UpdateCurrentItemModelMasterResult]:
        if data is None:
            return None
        return UpdateCurrentItemModelMasterResult()\
            .with_item(CurrentItemModelMaster.from_dict(data.get('item')))

    def to_dict(self) -> Dict[str, Any]:
        return {
            "item": self.item.to_dict() if self.item else None,
        }


class UpdateCurrentItemModelMasterFromGitHubResult(core.Gs2Result):
    item: CurrentItemModelMaster = None

    def with_item(self, item: CurrentItemModelMaster) -> UpdateCurrentItemModelMasterFromGitHubResult:
        self.item = item
        return self

    def get(self, key, default=None):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return default

    def __getitem__(self, key):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return None

    @staticmethod
    def from_dict(
        data: Dict[str, Any],
    ) -> Optional[UpdateCurrentItemModelMasterFromGitHubResult]:
        if data is None:
            return None
        return UpdateCurrentItemModelMasterFromGitHubResult()\
            .with_item(CurrentItemModelMaster.from_dict(data.get('item')))

    def to_dict(self) -> Dict[str, Any]:
        return {
            "item": self.item.to_dict() if self.item else None,
        }


class DescribeInventoriesResult(core.Gs2Result):
    items: List[Inventory] = None
    next_page_token: str = None

    def with_items(self, items: List[Inventory]) -> DescribeInventoriesResult:
        self.items = items
        return self

    def with_next_page_token(self, next_page_token: str) -> DescribeInventoriesResult:
        self.next_page_token = next_page_token
        return self

    def get(self, key, default=None):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return default

    def __getitem__(self, key):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return None

    @staticmethod
    def from_dict(
        data: Dict[str, Any],
    ) -> Optional[DescribeInventoriesResult]:
        if data is None:
            return None
        return DescribeInventoriesResult()\
            .with_items([
                Inventory.from_dict(data.get('items')[i])
                for i in range(len(data.get('items')) if data.get('items') else 0)
            ])\
            .with_next_page_token(data.get('nextPageToken'))

    def to_dict(self) -> Dict[str, Any]:
        return {
            "items": [
                self.items[i].to_dict() if self.items[i] else None
                for i in range(len(self.items) if self.items else 0)
            ],
            "nextPageToken": self.next_page_token,
        }


class DescribeInventoriesByUserIdResult(core.Gs2Result):
    items: List[Inventory] = None
    next_page_token: str = None

    def with_items(self, items: List[Inventory]) -> DescribeInventoriesByUserIdResult:
        self.items = items
        return self

    def with_next_page_token(self, next_page_token: str) -> DescribeInventoriesByUserIdResult:
        self.next_page_token = next_page_token
        return self

    def get(self, key, default=None):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return default

    def __getitem__(self, key):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return None

    @staticmethod
    def from_dict(
        data: Dict[str, Any],
    ) -> Optional[DescribeInventoriesByUserIdResult]:
        if data is None:
            return None
        return DescribeInventoriesByUserIdResult()\
            .with_items([
                Inventory.from_dict(data.get('items')[i])
                for i in range(len(data.get('items')) if data.get('items') else 0)
            ])\
            .with_next_page_token(data.get('nextPageToken'))

    def to_dict(self) -> Dict[str, Any]:
        return {
            "items": [
                self.items[i].to_dict() if self.items[i] else None
                for i in range(len(self.items) if self.items else 0)
            ],
            "nextPageToken": self.next_page_token,
        }


class GetInventoryResult(core.Gs2Result):
    item: Inventory = None

    def with_item(self, item: Inventory) -> GetInventoryResult:
        self.item = item
        return self

    def get(self, key, default=None):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return default

    def __getitem__(self, key):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return None

    @staticmethod
    def from_dict(
        data: Dict[str, Any],
    ) -> Optional[GetInventoryResult]:
        if data is None:
            return None
        return GetInventoryResult()\
            .with_item(Inventory.from_dict(data.get('item')))

    def to_dict(self) -> Dict[str, Any]:
        return {
            "item": self.item.to_dict() if self.item else None,
        }


class GetInventoryByUserIdResult(core.Gs2Result):
    item: Inventory = None

    def with_item(self, item: Inventory) -> GetInventoryByUserIdResult:
        self.item = item
        return self

    def get(self, key, default=None):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return default

    def __getitem__(self, key):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return None

    @staticmethod
    def from_dict(
        data: Dict[str, Any],
    ) -> Optional[GetInventoryByUserIdResult]:
        if data is None:
            return None
        return GetInventoryByUserIdResult()\
            .with_item(Inventory.from_dict(data.get('item')))

    def to_dict(self) -> Dict[str, Any]:
        return {
            "item": self.item.to_dict() if self.item else None,
        }


class AddCapacityByUserIdResult(core.Gs2Result):
    item: Inventory = None

    def with_item(self, item: Inventory) -> AddCapacityByUserIdResult:
        self.item = item
        return self

    def get(self, key, default=None):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return default

    def __getitem__(self, key):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return None

    @staticmethod
    def from_dict(
        data: Dict[str, Any],
    ) -> Optional[AddCapacityByUserIdResult]:
        if data is None:
            return None
        return AddCapacityByUserIdResult()\
            .with_item(Inventory.from_dict(data.get('item')))

    def to_dict(self) -> Dict[str, Any]:
        return {
            "item": self.item.to_dict() if self.item else None,
        }


class SetCapacityByUserIdResult(core.Gs2Result):
    item: Inventory = None

    def with_item(self, item: Inventory) -> SetCapacityByUserIdResult:
        self.item = item
        return self

    def get(self, key, default=None):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return default

    def __getitem__(self, key):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return None

    @staticmethod
    def from_dict(
        data: Dict[str, Any],
    ) -> Optional[SetCapacityByUserIdResult]:
        if data is None:
            return None
        return SetCapacityByUserIdResult()\
            .with_item(Inventory.from_dict(data.get('item')))

    def to_dict(self) -> Dict[str, Any]:
        return {
            "item": self.item.to_dict() if self.item else None,
        }


class DeleteInventoryByUserIdResult(core.Gs2Result):
    item: Inventory = None

    def with_item(self, item: Inventory) -> DeleteInventoryByUserIdResult:
        self.item = item
        return self

    def get(self, key, default=None):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return default

    def __getitem__(self, key):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return None

    @staticmethod
    def from_dict(
        data: Dict[str, Any],
    ) -> Optional[DeleteInventoryByUserIdResult]:
        if data is None:
            return None
        return DeleteInventoryByUserIdResult()\
            .with_item(Inventory.from_dict(data.get('item')))

    def to_dict(self) -> Dict[str, Any]:
        return {
            "item": self.item.to_dict() if self.item else None,
        }


class AddCapacityByStampSheetResult(core.Gs2Result):
    item: Inventory = None

    def with_item(self, item: Inventory) -> AddCapacityByStampSheetResult:
        self.item = item
        return self

    def get(self, key, default=None):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return default

    def __getitem__(self, key):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return None

    @staticmethod
    def from_dict(
        data: Dict[str, Any],
    ) -> Optional[AddCapacityByStampSheetResult]:
        if data is None:
            return None
        return AddCapacityByStampSheetResult()\
            .with_item(Inventory.from_dict(data.get('item')))

    def to_dict(self) -> Dict[str, Any]:
        return {
            "item": self.item.to_dict() if self.item else None,
        }


class SetCapacityByStampSheetResult(core.Gs2Result):
    item: Inventory = None

    def with_item(self, item: Inventory) -> SetCapacityByStampSheetResult:
        self.item = item
        return self

    def get(self, key, default=None):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return default

    def __getitem__(self, key):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return None

    @staticmethod
    def from_dict(
        data: Dict[str, Any],
    ) -> Optional[SetCapacityByStampSheetResult]:
        if data is None:
            return None
        return SetCapacityByStampSheetResult()\
            .with_item(Inventory.from_dict(data.get('item')))

    def to_dict(self) -> Dict[str, Any]:
        return {
            "item": self.item.to_dict() if self.item else None,
        }


class DescribeItemSetsResult(core.Gs2Result):
    items: List[ItemSet] = None
    next_page_token: str = None

    def with_items(self, items: List[ItemSet]) -> DescribeItemSetsResult:
        self.items = items
        return self

    def with_next_page_token(self, next_page_token: str) -> DescribeItemSetsResult:
        self.next_page_token = next_page_token
        return self

    def get(self, key, default=None):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return default

    def __getitem__(self, key):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return None

    @staticmethod
    def from_dict(
        data: Dict[str, Any],
    ) -> Optional[DescribeItemSetsResult]:
        if data is None:
            return None
        return DescribeItemSetsResult()\
            .with_items([
                ItemSet.from_dict(data.get('items')[i])
                for i in range(len(data.get('items')) if data.get('items') else 0)
            ])\
            .with_next_page_token(data.get('nextPageToken'))

    def to_dict(self) -> Dict[str, Any]:
        return {
            "items": [
                self.items[i].to_dict() if self.items[i] else None
                for i in range(len(self.items) if self.items else 0)
            ],
            "nextPageToken": self.next_page_token,
        }


class DescribeItemSetsByUserIdResult(core.Gs2Result):
    items: List[ItemSet] = None
    next_page_token: str = None

    def with_items(self, items: List[ItemSet]) -> DescribeItemSetsByUserIdResult:
        self.items = items
        return self

    def with_next_page_token(self, next_page_token: str) -> DescribeItemSetsByUserIdResult:
        self.next_page_token = next_page_token
        return self

    def get(self, key, default=None):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return default

    def __getitem__(self, key):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return None

    @staticmethod
    def from_dict(
        data: Dict[str, Any],
    ) -> Optional[DescribeItemSetsByUserIdResult]:
        if data is None:
            return None
        return DescribeItemSetsByUserIdResult()\
            .with_items([
                ItemSet.from_dict(data.get('items')[i])
                for i in range(len(data.get('items')) if data.get('items') else 0)
            ])\
            .with_next_page_token(data.get('nextPageToken'))

    def to_dict(self) -> Dict[str, Any]:
        return {
            "items": [
                self.items[i].to_dict() if self.items[i] else None
                for i in range(len(self.items) if self.items else 0)
            ],
            "nextPageToken": self.next_page_token,
        }


class GetItemSetResult(core.Gs2Result):
    items: List[ItemSet] = None
    item_model: ItemModel = None
    inventory: Inventory = None

    def with_items(self, items: List[ItemSet]) -> GetItemSetResult:
        self.items = items
        return self

    def with_item_model(self, item_model: ItemModel) -> GetItemSetResult:
        self.item_model = item_model
        return self

    def with_inventory(self, inventory: Inventory) -> GetItemSetResult:
        self.inventory = inventory
        return self

    def get(self, key, default=None):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return default

    def __getitem__(self, key):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return None

    @staticmethod
    def from_dict(
        data: Dict[str, Any],
    ) -> Optional[GetItemSetResult]:
        if data is None:
            return None
        return GetItemSetResult()\
            .with_items([
                ItemSet.from_dict(data.get('items')[i])
                for i in range(len(data.get('items')) if data.get('items') else 0)
            ])\
            .with_item_model(ItemModel.from_dict(data.get('itemModel')))\
            .with_inventory(Inventory.from_dict(data.get('inventory')))

    def to_dict(self) -> Dict[str, Any]:
        return {
            "items": [
                self.items[i].to_dict() if self.items[i] else None
                for i in range(len(self.items) if self.items else 0)
            ],
            "itemModel": self.item_model.to_dict() if self.item_model else None,
            "inventory": self.inventory.to_dict() if self.inventory else None,
        }


class GetItemSetByUserIdResult(core.Gs2Result):
    items: List[ItemSet] = None
    item_model: ItemModel = None
    inventory: Inventory = None

    def with_items(self, items: List[ItemSet]) -> GetItemSetByUserIdResult:
        self.items = items
        return self

    def with_item_model(self, item_model: ItemModel) -> GetItemSetByUserIdResult:
        self.item_model = item_model
        return self

    def with_inventory(self, inventory: Inventory) -> GetItemSetByUserIdResult:
        self.inventory = inventory
        return self

    def get(self, key, default=None):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return default

    def __getitem__(self, key):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return None

    @staticmethod
    def from_dict(
        data: Dict[str, Any],
    ) -> Optional[GetItemSetByUserIdResult]:
        if data is None:
            return None
        return GetItemSetByUserIdResult()\
            .with_items([
                ItemSet.from_dict(data.get('items')[i])
                for i in range(len(data.get('items')) if data.get('items') else 0)
            ])\
            .with_item_model(ItemModel.from_dict(data.get('itemModel')))\
            .with_inventory(Inventory.from_dict(data.get('inventory')))

    def to_dict(self) -> Dict[str, Any]:
        return {
            "items": [
                self.items[i].to_dict() if self.items[i] else None
                for i in range(len(self.items) if self.items else 0)
            ],
            "itemModel": self.item_model.to_dict() if self.item_model else None,
            "inventory": self.inventory.to_dict() if self.inventory else None,
        }


class GetItemWithSignatureResult(core.Gs2Result):
    items: List[ItemSet] = None
    item_model: ItemModel = None
    inventory: Inventory = None
    body: str = None
    signature: str = None

    def with_items(self, items: List[ItemSet]) -> GetItemWithSignatureResult:
        self.items = items
        return self

    def with_item_model(self, item_model: ItemModel) -> GetItemWithSignatureResult:
        self.item_model = item_model
        return self

    def with_inventory(self, inventory: Inventory) -> GetItemWithSignatureResult:
        self.inventory = inventory
        return self

    def with_body(self, body: str) -> GetItemWithSignatureResult:
        self.body = body
        return self

    def with_signature(self, signature: str) -> GetItemWithSignatureResult:
        self.signature = signature
        return self

    def get(self, key, default=None):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return default

    def __getitem__(self, key):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return None

    @staticmethod
    def from_dict(
        data: Dict[str, Any],
    ) -> Optional[GetItemWithSignatureResult]:
        if data is None:
            return None
        return GetItemWithSignatureResult()\
            .with_items([
                ItemSet.from_dict(data.get('items')[i])
                for i in range(len(data.get('items')) if data.get('items') else 0)
            ])\
            .with_item_model(ItemModel.from_dict(data.get('itemModel')))\
            .with_inventory(Inventory.from_dict(data.get('inventory')))\
            .with_body(data.get('body'))\
            .with_signature(data.get('signature'))

    def to_dict(self) -> Dict[str, Any]:
        return {
            "items": [
                self.items[i].to_dict() if self.items[i] else None
                for i in range(len(self.items) if self.items else 0)
            ],
            "itemModel": self.item_model.to_dict() if self.item_model else None,
            "inventory": self.inventory.to_dict() if self.inventory else None,
            "body": self.body,
            "signature": self.signature,
        }


class GetItemWithSignatureByUserIdResult(core.Gs2Result):
    items: List[ItemSet] = None
    item_model: ItemModel = None
    inventory: Inventory = None
    body: str = None
    signature: str = None

    def with_items(self, items: List[ItemSet]) -> GetItemWithSignatureByUserIdResult:
        self.items = items
        return self

    def with_item_model(self, item_model: ItemModel) -> GetItemWithSignatureByUserIdResult:
        self.item_model = item_model
        return self

    def with_inventory(self, inventory: Inventory) -> GetItemWithSignatureByUserIdResult:
        self.inventory = inventory
        return self

    def with_body(self, body: str) -> GetItemWithSignatureByUserIdResult:
        self.body = body
        return self

    def with_signature(self, signature: str) -> GetItemWithSignatureByUserIdResult:
        self.signature = signature
        return self

    def get(self, key, default=None):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return default

    def __getitem__(self, key):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return None

    @staticmethod
    def from_dict(
        data: Dict[str, Any],
    ) -> Optional[GetItemWithSignatureByUserIdResult]:
        if data is None:
            return None
        return GetItemWithSignatureByUserIdResult()\
            .with_items([
                ItemSet.from_dict(data.get('items')[i])
                for i in range(len(data.get('items')) if data.get('items') else 0)
            ])\
            .with_item_model(ItemModel.from_dict(data.get('itemModel')))\
            .with_inventory(Inventory.from_dict(data.get('inventory')))\
            .with_body(data.get('body'))\
            .with_signature(data.get('signature'))

    def to_dict(self) -> Dict[str, Any]:
        return {
            "items": [
                self.items[i].to_dict() if self.items[i] else None
                for i in range(len(self.items) if self.items else 0)
            ],
            "itemModel": self.item_model.to_dict() if self.item_model else None,
            "inventory": self.inventory.to_dict() if self.inventory else None,
            "body": self.body,
            "signature": self.signature,
        }


class AcquireItemSetByUserIdResult(core.Gs2Result):
    items: List[ItemSet] = None
    item_model: ItemModel = None
    inventory: Inventory = None
    overflow_count: int = None

    def with_items(self, items: List[ItemSet]) -> AcquireItemSetByUserIdResult:
        self.items = items
        return self

    def with_item_model(self, item_model: ItemModel) -> AcquireItemSetByUserIdResult:
        self.item_model = item_model
        return self

    def with_inventory(self, inventory: Inventory) -> AcquireItemSetByUserIdResult:
        self.inventory = inventory
        return self

    def with_overflow_count(self, overflow_count: int) -> AcquireItemSetByUserIdResult:
        self.overflow_count = overflow_count
        return self

    def get(self, key, default=None):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return default

    def __getitem__(self, key):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return None

    @staticmethod
    def from_dict(
        data: Dict[str, Any],
    ) -> Optional[AcquireItemSetByUserIdResult]:
        if data is None:
            return None
        return AcquireItemSetByUserIdResult()\
            .with_items([
                ItemSet.from_dict(data.get('items')[i])
                for i in range(len(data.get('items')) if data.get('items') else 0)
            ])\
            .with_item_model(ItemModel.from_dict(data.get('itemModel')))\
            .with_inventory(Inventory.from_dict(data.get('inventory')))\
            .with_overflow_count(data.get('overflowCount'))

    def to_dict(self) -> Dict[str, Any]:
        return {
            "items": [
                self.items[i].to_dict() if self.items[i] else None
                for i in range(len(self.items) if self.items else 0)
            ],
            "itemModel": self.item_model.to_dict() if self.item_model else None,
            "inventory": self.inventory.to_dict() if self.inventory else None,
            "overflowCount": self.overflow_count,
        }


class ConsumeItemSetResult(core.Gs2Result):
    items: List[ItemSet] = None
    item_model: ItemModel = None
    inventory: Inventory = None

    def with_items(self, items: List[ItemSet]) -> ConsumeItemSetResult:
        self.items = items
        return self

    def with_item_model(self, item_model: ItemModel) -> ConsumeItemSetResult:
        self.item_model = item_model
        return self

    def with_inventory(self, inventory: Inventory) -> ConsumeItemSetResult:
        self.inventory = inventory
        return self

    def get(self, key, default=None):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return default

    def __getitem__(self, key):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return None

    @staticmethod
    def from_dict(
        data: Dict[str, Any],
    ) -> Optional[ConsumeItemSetResult]:
        if data is None:
            return None
        return ConsumeItemSetResult()\
            .with_items([
                ItemSet.from_dict(data.get('items')[i])
                for i in range(len(data.get('items')) if data.get('items') else 0)
            ])\
            .with_item_model(ItemModel.from_dict(data.get('itemModel')))\
            .with_inventory(Inventory.from_dict(data.get('inventory')))

    def to_dict(self) -> Dict[str, Any]:
        return {
            "items": [
                self.items[i].to_dict() if self.items[i] else None
                for i in range(len(self.items) if self.items else 0)
            ],
            "itemModel": self.item_model.to_dict() if self.item_model else None,
            "inventory": self.inventory.to_dict() if self.inventory else None,
        }


class ConsumeItemSetByUserIdResult(core.Gs2Result):
    items: List[ItemSet] = None
    item_model: ItemModel = None
    inventory: Inventory = None

    def with_items(self, items: List[ItemSet]) -> ConsumeItemSetByUserIdResult:
        self.items = items
        return self

    def with_item_model(self, item_model: ItemModel) -> ConsumeItemSetByUserIdResult:
        self.item_model = item_model
        return self

    def with_inventory(self, inventory: Inventory) -> ConsumeItemSetByUserIdResult:
        self.inventory = inventory
        return self

    def get(self, key, default=None):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return default

    def __getitem__(self, key):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return None

    @staticmethod
    def from_dict(
        data: Dict[str, Any],
    ) -> Optional[ConsumeItemSetByUserIdResult]:
        if data is None:
            return None
        return ConsumeItemSetByUserIdResult()\
            .with_items([
                ItemSet.from_dict(data.get('items')[i])
                for i in range(len(data.get('items')) if data.get('items') else 0)
            ])\
            .with_item_model(ItemModel.from_dict(data.get('itemModel')))\
            .with_inventory(Inventory.from_dict(data.get('inventory')))

    def to_dict(self) -> Dict[str, Any]:
        return {
            "items": [
                self.items[i].to_dict() if self.items[i] else None
                for i in range(len(self.items) if self.items else 0)
            ],
            "itemModel": self.item_model.to_dict() if self.item_model else None,
            "inventory": self.inventory.to_dict() if self.inventory else None,
        }


class DeleteItemSetByUserIdResult(core.Gs2Result):
    items: List[ItemSet] = None
    item_model: ItemModel = None
    inventory: Inventory = None

    def with_items(self, items: List[ItemSet]) -> DeleteItemSetByUserIdResult:
        self.items = items
        return self

    def with_item_model(self, item_model: ItemModel) -> DeleteItemSetByUserIdResult:
        self.item_model = item_model
        return self

    def with_inventory(self, inventory: Inventory) -> DeleteItemSetByUserIdResult:
        self.inventory = inventory
        return self

    def get(self, key, default=None):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return default

    def __getitem__(self, key):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return None

    @staticmethod
    def from_dict(
        data: Dict[str, Any],
    ) -> Optional[DeleteItemSetByUserIdResult]:
        if data is None:
            return None
        return DeleteItemSetByUserIdResult()\
            .with_items([
                ItemSet.from_dict(data.get('items')[i])
                for i in range(len(data.get('items')) if data.get('items') else 0)
            ])\
            .with_item_model(ItemModel.from_dict(data.get('itemModel')))\
            .with_inventory(Inventory.from_dict(data.get('inventory')))

    def to_dict(self) -> Dict[str, Any]:
        return {
            "items": [
                self.items[i].to_dict() if self.items[i] else None
                for i in range(len(self.items) if self.items else 0)
            ],
            "itemModel": self.item_model.to_dict() if self.item_model else None,
            "inventory": self.inventory.to_dict() if self.inventory else None,
        }


class AcquireItemSetByStampSheetResult(core.Gs2Result):
    items: List[ItemSet] = None
    item_model: ItemModel = None
    inventory: Inventory = None
    overflow_count: int = None

    def with_items(self, items: List[ItemSet]) -> AcquireItemSetByStampSheetResult:
        self.items = items
        return self

    def with_item_model(self, item_model: ItemModel) -> AcquireItemSetByStampSheetResult:
        self.item_model = item_model
        return self

    def with_inventory(self, inventory: Inventory) -> AcquireItemSetByStampSheetResult:
        self.inventory = inventory
        return self

    def with_overflow_count(self, overflow_count: int) -> AcquireItemSetByStampSheetResult:
        self.overflow_count = overflow_count
        return self

    def get(self, key, default=None):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return default

    def __getitem__(self, key):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return None

    @staticmethod
    def from_dict(
        data: Dict[str, Any],
    ) -> Optional[AcquireItemSetByStampSheetResult]:
        if data is None:
            return None
        return AcquireItemSetByStampSheetResult()\
            .with_items([
                ItemSet.from_dict(data.get('items')[i])
                for i in range(len(data.get('items')) if data.get('items') else 0)
            ])\
            .with_item_model(ItemModel.from_dict(data.get('itemModel')))\
            .with_inventory(Inventory.from_dict(data.get('inventory')))\
            .with_overflow_count(data.get('overflowCount'))

    def to_dict(self) -> Dict[str, Any]:
        return {
            "items": [
                self.items[i].to_dict() if self.items[i] else None
                for i in range(len(self.items) if self.items else 0)
            ],
            "itemModel": self.item_model.to_dict() if self.item_model else None,
            "inventory": self.inventory.to_dict() if self.inventory else None,
            "overflowCount": self.overflow_count,
        }


class ConsumeItemSetByStampTaskResult(core.Gs2Result):
    items: List[ItemSet] = None
    item_model: ItemModel = None
    inventory: Inventory = None
    new_context_stack: str = None

    def with_items(self, items: List[ItemSet]) -> ConsumeItemSetByStampTaskResult:
        self.items = items
        return self

    def with_item_model(self, item_model: ItemModel) -> ConsumeItemSetByStampTaskResult:
        self.item_model = item_model
        return self

    def with_inventory(self, inventory: Inventory) -> ConsumeItemSetByStampTaskResult:
        self.inventory = inventory
        return self

    def with_new_context_stack(self, new_context_stack: str) -> ConsumeItemSetByStampTaskResult:
        self.new_context_stack = new_context_stack
        return self

    def get(self, key, default=None):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return default

    def __getitem__(self, key):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return None

    @staticmethod
    def from_dict(
        data: Dict[str, Any],
    ) -> Optional[ConsumeItemSetByStampTaskResult]:
        if data is None:
            return None
        return ConsumeItemSetByStampTaskResult()\
            .with_items([
                ItemSet.from_dict(data.get('items')[i])
                for i in range(len(data.get('items')) if data.get('items') else 0)
            ])\
            .with_item_model(ItemModel.from_dict(data.get('itemModel')))\
            .with_inventory(Inventory.from_dict(data.get('inventory')))\
            .with_new_context_stack(data.get('newContextStack'))

    def to_dict(self) -> Dict[str, Any]:
        return {
            "items": [
                self.items[i].to_dict() if self.items[i] else None
                for i in range(len(self.items) if self.items else 0)
            ],
            "itemModel": self.item_model.to_dict() if self.item_model else None,
            "inventory": self.inventory.to_dict() if self.inventory else None,
            "newContextStack": self.new_context_stack,
        }


class DescribeReferenceOfResult(core.Gs2Result):
    items: List[str] = None
    item_set: ItemSet = None
    item_model: ItemModel = None
    inventory: Inventory = None

    def with_items(self, items: List[str]) -> DescribeReferenceOfResult:
        self.items = items
        return self

    def with_item_set(self, item_set: ItemSet) -> DescribeReferenceOfResult:
        self.item_set = item_set
        return self

    def with_item_model(self, item_model: ItemModel) -> DescribeReferenceOfResult:
        self.item_model = item_model
        return self

    def with_inventory(self, inventory: Inventory) -> DescribeReferenceOfResult:
        self.inventory = inventory
        return self

    def get(self, key, default=None):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return default

    def __getitem__(self, key):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return None

    @staticmethod
    def from_dict(
        data: Dict[str, Any],
    ) -> Optional[DescribeReferenceOfResult]:
        if data is None:
            return None
        return DescribeReferenceOfResult()\
            .with_items([
                data.get('items')[i]
                for i in range(len(data.get('items')) if data.get('items') else 0)
            ])\
            .with_item_set(ItemSet.from_dict(data.get('itemSet')))\
            .with_item_model(ItemModel.from_dict(data.get('itemModel')))\
            .with_inventory(Inventory.from_dict(data.get('inventory')))

    def to_dict(self) -> Dict[str, Any]:
        return {
            "items": [
                self.items[i]
                for i in range(len(self.items) if self.items else 0)
            ],
            "itemSet": self.item_set.to_dict() if self.item_set else None,
            "itemModel": self.item_model.to_dict() if self.item_model else None,
            "inventory": self.inventory.to_dict() if self.inventory else None,
        }


class DescribeReferenceOfByUserIdResult(core.Gs2Result):
    items: List[str] = None
    item_set: ItemSet = None
    item_model: ItemModel = None
    inventory: Inventory = None

    def with_items(self, items: List[str]) -> DescribeReferenceOfByUserIdResult:
        self.items = items
        return self

    def with_item_set(self, item_set: ItemSet) -> DescribeReferenceOfByUserIdResult:
        self.item_set = item_set
        return self

    def with_item_model(self, item_model: ItemModel) -> DescribeReferenceOfByUserIdResult:
        self.item_model = item_model
        return self

    def with_inventory(self, inventory: Inventory) -> DescribeReferenceOfByUserIdResult:
        self.inventory = inventory
        return self

    def get(self, key, default=None):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return default

    def __getitem__(self, key):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return None

    @staticmethod
    def from_dict(
        data: Dict[str, Any],
    ) -> Optional[DescribeReferenceOfByUserIdResult]:
        if data is None:
            return None
        return DescribeReferenceOfByUserIdResult()\
            .with_items([
                data.get('items')[i]
                for i in range(len(data.get('items')) if data.get('items') else 0)
            ])\
            .with_item_set(ItemSet.from_dict(data.get('itemSet')))\
            .with_item_model(ItemModel.from_dict(data.get('itemModel')))\
            .with_inventory(Inventory.from_dict(data.get('inventory')))

    def to_dict(self) -> Dict[str, Any]:
        return {
            "items": [
                self.items[i]
                for i in range(len(self.items) if self.items else 0)
            ],
            "itemSet": self.item_set.to_dict() if self.item_set else None,
            "itemModel": self.item_model.to_dict() if self.item_model else None,
            "inventory": self.inventory.to_dict() if self.inventory else None,
        }


class GetReferenceOfResult(core.Gs2Result):
    item: List[str] = None
    item_set: ItemSet = None
    item_model: ItemModel = None
    inventory: Inventory = None

    def with_item(self, item: List[str]) -> GetReferenceOfResult:
        self.item = item
        return self

    def with_item_set(self, item_set: ItemSet) -> GetReferenceOfResult:
        self.item_set = item_set
        return self

    def with_item_model(self, item_model: ItemModel) -> GetReferenceOfResult:
        self.item_model = item_model
        return self

    def with_inventory(self, inventory: Inventory) -> GetReferenceOfResult:
        self.inventory = inventory
        return self

    def get(self, key, default=None):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return default

    def __getitem__(self, key):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return None

    @staticmethod
    def from_dict(
        data: Dict[str, Any],
    ) -> Optional[GetReferenceOfResult]:
        if data is None:
            return None
        return GetReferenceOfResult()\
            .with_item([
                data.get('item')[i]
                for i in range(len(data.get('item')) if data.get('item') else 0)
            ])\
            .with_item_set(ItemSet.from_dict(data.get('itemSet')))\
            .with_item_model(ItemModel.from_dict(data.get('itemModel')))\
            .with_inventory(Inventory.from_dict(data.get('inventory')))

    def to_dict(self) -> Dict[str, Any]:
        return {
            "item": [
                self.item[i]
                for i in range(len(self.item) if self.item else 0)
            ],
            "itemSet": self.item_set.to_dict() if self.item_set else None,
            "itemModel": self.item_model.to_dict() if self.item_model else None,
            "inventory": self.inventory.to_dict() if self.inventory else None,
        }


class GetReferenceOfByUserIdResult(core.Gs2Result):
    item: List[str] = None
    item_set: ItemSet = None
    item_model: ItemModel = None
    inventory: Inventory = None

    def with_item(self, item: List[str]) -> GetReferenceOfByUserIdResult:
        self.item = item
        return self

    def with_item_set(self, item_set: ItemSet) -> GetReferenceOfByUserIdResult:
        self.item_set = item_set
        return self

    def with_item_model(self, item_model: ItemModel) -> GetReferenceOfByUserIdResult:
        self.item_model = item_model
        return self

    def with_inventory(self, inventory: Inventory) -> GetReferenceOfByUserIdResult:
        self.inventory = inventory
        return self

    def get(self, key, default=None):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return default

    def __getitem__(self, key):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return None

    @staticmethod
    def from_dict(
        data: Dict[str, Any],
    ) -> Optional[GetReferenceOfByUserIdResult]:
        if data is None:
            return None
        return GetReferenceOfByUserIdResult()\
            .with_item([
                data.get('item')[i]
                for i in range(len(data.get('item')) if data.get('item') else 0)
            ])\
            .with_item_set(ItemSet.from_dict(data.get('itemSet')))\
            .with_item_model(ItemModel.from_dict(data.get('itemModel')))\
            .with_inventory(Inventory.from_dict(data.get('inventory')))

    def to_dict(self) -> Dict[str, Any]:
        return {
            "item": [
                self.item[i]
                for i in range(len(self.item) if self.item else 0)
            ],
            "itemSet": self.item_set.to_dict() if self.item_set else None,
            "itemModel": self.item_model.to_dict() if self.item_model else None,
            "inventory": self.inventory.to_dict() if self.inventory else None,
        }


class VerifyReferenceOfResult(core.Gs2Result):
    item: List[str] = None
    item_set: ItemSet = None
    item_model: ItemModel = None
    inventory: Inventory = None

    def with_item(self, item: List[str]) -> VerifyReferenceOfResult:
        self.item = item
        return self

    def with_item_set(self, item_set: ItemSet) -> VerifyReferenceOfResult:
        self.item_set = item_set
        return self

    def with_item_model(self, item_model: ItemModel) -> VerifyReferenceOfResult:
        self.item_model = item_model
        return self

    def with_inventory(self, inventory: Inventory) -> VerifyReferenceOfResult:
        self.inventory = inventory
        return self

    def get(self, key, default=None):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return default

    def __getitem__(self, key):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return None

    @staticmethod
    def from_dict(
        data: Dict[str, Any],
    ) -> Optional[VerifyReferenceOfResult]:
        if data is None:
            return None
        return VerifyReferenceOfResult()\
            .with_item([
                data.get('item')[i]
                for i in range(len(data.get('item')) if data.get('item') else 0)
            ])\
            .with_item_set(ItemSet.from_dict(data.get('itemSet')))\
            .with_item_model(ItemModel.from_dict(data.get('itemModel')))\
            .with_inventory(Inventory.from_dict(data.get('inventory')))

    def to_dict(self) -> Dict[str, Any]:
        return {
            "item": [
                self.item[i]
                for i in range(len(self.item) if self.item else 0)
            ],
            "itemSet": self.item_set.to_dict() if self.item_set else None,
            "itemModel": self.item_model.to_dict() if self.item_model else None,
            "inventory": self.inventory.to_dict() if self.inventory else None,
        }


class VerifyReferenceOfByUserIdResult(core.Gs2Result):
    item: List[str] = None
    item_set: ItemSet = None
    item_model: ItemModel = None
    inventory: Inventory = None

    def with_item(self, item: List[str]) -> VerifyReferenceOfByUserIdResult:
        self.item = item
        return self

    def with_item_set(self, item_set: ItemSet) -> VerifyReferenceOfByUserIdResult:
        self.item_set = item_set
        return self

    def with_item_model(self, item_model: ItemModel) -> VerifyReferenceOfByUserIdResult:
        self.item_model = item_model
        return self

    def with_inventory(self, inventory: Inventory) -> VerifyReferenceOfByUserIdResult:
        self.inventory = inventory
        return self

    def get(self, key, default=None):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return default

    def __getitem__(self, key):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return None

    @staticmethod
    def from_dict(
        data: Dict[str, Any],
    ) -> Optional[VerifyReferenceOfByUserIdResult]:
        if data is None:
            return None
        return VerifyReferenceOfByUserIdResult()\
            .with_item([
                data.get('item')[i]
                for i in range(len(data.get('item')) if data.get('item') else 0)
            ])\
            .with_item_set(ItemSet.from_dict(data.get('itemSet')))\
            .with_item_model(ItemModel.from_dict(data.get('itemModel')))\
            .with_inventory(Inventory.from_dict(data.get('inventory')))

    def to_dict(self) -> Dict[str, Any]:
        return {
            "item": [
                self.item[i]
                for i in range(len(self.item) if self.item else 0)
            ],
            "itemSet": self.item_set.to_dict() if self.item_set else None,
            "itemModel": self.item_model.to_dict() if self.item_model else None,
            "inventory": self.inventory.to_dict() if self.inventory else None,
        }


class AddReferenceOfResult(core.Gs2Result):
    item: List[str] = None
    item_set: ItemSet = None
    item_model: ItemModel = None
    inventory: Inventory = None

    def with_item(self, item: List[str]) -> AddReferenceOfResult:
        self.item = item
        return self

    def with_item_set(self, item_set: ItemSet) -> AddReferenceOfResult:
        self.item_set = item_set
        return self

    def with_item_model(self, item_model: ItemModel) -> AddReferenceOfResult:
        self.item_model = item_model
        return self

    def with_inventory(self, inventory: Inventory) -> AddReferenceOfResult:
        self.inventory = inventory
        return self

    def get(self, key, default=None):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return default

    def __getitem__(self, key):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return None

    @staticmethod
    def from_dict(
        data: Dict[str, Any],
    ) -> Optional[AddReferenceOfResult]:
        if data is None:
            return None
        return AddReferenceOfResult()\
            .with_item([
                data.get('item')[i]
                for i in range(len(data.get('item')) if data.get('item') else 0)
            ])\
            .with_item_set(ItemSet.from_dict(data.get('itemSet')))\
            .with_item_model(ItemModel.from_dict(data.get('itemModel')))\
            .with_inventory(Inventory.from_dict(data.get('inventory')))

    def to_dict(self) -> Dict[str, Any]:
        return {
            "item": [
                self.item[i]
                for i in range(len(self.item) if self.item else 0)
            ],
            "itemSet": self.item_set.to_dict() if self.item_set else None,
            "itemModel": self.item_model.to_dict() if self.item_model else None,
            "inventory": self.inventory.to_dict() if self.inventory else None,
        }


class AddReferenceOfByUserIdResult(core.Gs2Result):
    item: List[str] = None
    item_set: ItemSet = None
    item_model: ItemModel = None
    inventory: Inventory = None

    def with_item(self, item: List[str]) -> AddReferenceOfByUserIdResult:
        self.item = item
        return self

    def with_item_set(self, item_set: ItemSet) -> AddReferenceOfByUserIdResult:
        self.item_set = item_set
        return self

    def with_item_model(self, item_model: ItemModel) -> AddReferenceOfByUserIdResult:
        self.item_model = item_model
        return self

    def with_inventory(self, inventory: Inventory) -> AddReferenceOfByUserIdResult:
        self.inventory = inventory
        return self

    def get(self, key, default=None):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return default

    def __getitem__(self, key):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return None

    @staticmethod
    def from_dict(
        data: Dict[str, Any],
    ) -> Optional[AddReferenceOfByUserIdResult]:
        if data is None:
            return None
        return AddReferenceOfByUserIdResult()\
            .with_item([
                data.get('item')[i]
                for i in range(len(data.get('item')) if data.get('item') else 0)
            ])\
            .with_item_set(ItemSet.from_dict(data.get('itemSet')))\
            .with_item_model(ItemModel.from_dict(data.get('itemModel')))\
            .with_inventory(Inventory.from_dict(data.get('inventory')))

    def to_dict(self) -> Dict[str, Any]:
        return {
            "item": [
                self.item[i]
                for i in range(len(self.item) if self.item else 0)
            ],
            "itemSet": self.item_set.to_dict() if self.item_set else None,
            "itemModel": self.item_model.to_dict() if self.item_model else None,
            "inventory": self.inventory.to_dict() if self.inventory else None,
        }


class DeleteReferenceOfResult(core.Gs2Result):
    item: List[str] = None
    item_set: ItemSet = None
    item_model: ItemModel = None
    inventory: Inventory = None

    def with_item(self, item: List[str]) -> DeleteReferenceOfResult:
        self.item = item
        return self

    def with_item_set(self, item_set: ItemSet) -> DeleteReferenceOfResult:
        self.item_set = item_set
        return self

    def with_item_model(self, item_model: ItemModel) -> DeleteReferenceOfResult:
        self.item_model = item_model
        return self

    def with_inventory(self, inventory: Inventory) -> DeleteReferenceOfResult:
        self.inventory = inventory
        return self

    def get(self, key, default=None):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return default

    def __getitem__(self, key):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return None

    @staticmethod
    def from_dict(
        data: Dict[str, Any],
    ) -> Optional[DeleteReferenceOfResult]:
        if data is None:
            return None
        return DeleteReferenceOfResult()\
            .with_item([
                data.get('item')[i]
                for i in range(len(data.get('item')) if data.get('item') else 0)
            ])\
            .with_item_set(ItemSet.from_dict(data.get('itemSet')))\
            .with_item_model(ItemModel.from_dict(data.get('itemModel')))\
            .with_inventory(Inventory.from_dict(data.get('inventory')))

    def to_dict(self) -> Dict[str, Any]:
        return {
            "item": [
                self.item[i]
                for i in range(len(self.item) if self.item else 0)
            ],
            "itemSet": self.item_set.to_dict() if self.item_set else None,
            "itemModel": self.item_model.to_dict() if self.item_model else None,
            "inventory": self.inventory.to_dict() if self.inventory else None,
        }


class DeleteReferenceOfByUserIdResult(core.Gs2Result):
    item: List[str] = None
    item_set: ItemSet = None
    item_model: ItemModel = None
    inventory: Inventory = None

    def with_item(self, item: List[str]) -> DeleteReferenceOfByUserIdResult:
        self.item = item
        return self

    def with_item_set(self, item_set: ItemSet) -> DeleteReferenceOfByUserIdResult:
        self.item_set = item_set
        return self

    def with_item_model(self, item_model: ItemModel) -> DeleteReferenceOfByUserIdResult:
        self.item_model = item_model
        return self

    def with_inventory(self, inventory: Inventory) -> DeleteReferenceOfByUserIdResult:
        self.inventory = inventory
        return self

    def get(self, key, default=None):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return default

    def __getitem__(self, key):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return None

    @staticmethod
    def from_dict(
        data: Dict[str, Any],
    ) -> Optional[DeleteReferenceOfByUserIdResult]:
        if data is None:
            return None
        return DeleteReferenceOfByUserIdResult()\
            .with_item([
                data.get('item')[i]
                for i in range(len(data.get('item')) if data.get('item') else 0)
            ])\
            .with_item_set(ItemSet.from_dict(data.get('itemSet')))\
            .with_item_model(ItemModel.from_dict(data.get('itemModel')))\
            .with_inventory(Inventory.from_dict(data.get('inventory')))

    def to_dict(self) -> Dict[str, Any]:
        return {
            "item": [
                self.item[i]
                for i in range(len(self.item) if self.item else 0)
            ],
            "itemSet": self.item_set.to_dict() if self.item_set else None,
            "itemModel": self.item_model.to_dict() if self.item_model else None,
            "inventory": self.inventory.to_dict() if self.inventory else None,
        }


class AddReferenceOfItemSetByStampSheetResult(core.Gs2Result):
    item: List[str] = None
    item_set: ItemSet = None
    item_model: ItemModel = None
    inventory: Inventory = None

    def with_item(self, item: List[str]) -> AddReferenceOfItemSetByStampSheetResult:
        self.item = item
        return self

    def with_item_set(self, item_set: ItemSet) -> AddReferenceOfItemSetByStampSheetResult:
        self.item_set = item_set
        return self

    def with_item_model(self, item_model: ItemModel) -> AddReferenceOfItemSetByStampSheetResult:
        self.item_model = item_model
        return self

    def with_inventory(self, inventory: Inventory) -> AddReferenceOfItemSetByStampSheetResult:
        self.inventory = inventory
        return self

    def get(self, key, default=None):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return default

    def __getitem__(self, key):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return None

    @staticmethod
    def from_dict(
        data: Dict[str, Any],
    ) -> Optional[AddReferenceOfItemSetByStampSheetResult]:
        if data is None:
            return None
        return AddReferenceOfItemSetByStampSheetResult()\
            .with_item([
                data.get('item')[i]
                for i in range(len(data.get('item')) if data.get('item') else 0)
            ])\
            .with_item_set(ItemSet.from_dict(data.get('itemSet')))\
            .with_item_model(ItemModel.from_dict(data.get('itemModel')))\
            .with_inventory(Inventory.from_dict(data.get('inventory')))

    def to_dict(self) -> Dict[str, Any]:
        return {
            "item": [
                self.item[i]
                for i in range(len(self.item) if self.item else 0)
            ],
            "itemSet": self.item_set.to_dict() if self.item_set else None,
            "itemModel": self.item_model.to_dict() if self.item_model else None,
            "inventory": self.inventory.to_dict() if self.inventory else None,
        }


class DeleteReferenceOfItemSetByStampSheetResult(core.Gs2Result):
    item: List[str] = None
    item_set: ItemSet = None
    item_model: ItemModel = None
    inventory: Inventory = None

    def with_item(self, item: List[str]) -> DeleteReferenceOfItemSetByStampSheetResult:
        self.item = item
        return self

    def with_item_set(self, item_set: ItemSet) -> DeleteReferenceOfItemSetByStampSheetResult:
        self.item_set = item_set
        return self

    def with_item_model(self, item_model: ItemModel) -> DeleteReferenceOfItemSetByStampSheetResult:
        self.item_model = item_model
        return self

    def with_inventory(self, inventory: Inventory) -> DeleteReferenceOfItemSetByStampSheetResult:
        self.inventory = inventory
        return self

    def get(self, key, default=None):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return default

    def __getitem__(self, key):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return None

    @staticmethod
    def from_dict(
        data: Dict[str, Any],
    ) -> Optional[DeleteReferenceOfItemSetByStampSheetResult]:
        if data is None:
            return None
        return DeleteReferenceOfItemSetByStampSheetResult()\
            .with_item([
                data.get('item')[i]
                for i in range(len(data.get('item')) if data.get('item') else 0)
            ])\
            .with_item_set(ItemSet.from_dict(data.get('itemSet')))\
            .with_item_model(ItemModel.from_dict(data.get('itemModel')))\
            .with_inventory(Inventory.from_dict(data.get('inventory')))

    def to_dict(self) -> Dict[str, Any]:
        return {
            "item": [
                self.item[i]
                for i in range(len(self.item) if self.item else 0)
            ],
            "itemSet": self.item_set.to_dict() if self.item_set else None,
            "itemModel": self.item_model.to_dict() if self.item_model else None,
            "inventory": self.inventory.to_dict() if self.inventory else None,
        }


class VerifyReferenceOfByStampTaskResult(core.Gs2Result):
    item: List[str] = None
    item_set: ItemSet = None
    item_model: ItemModel = None
    inventory: Inventory = None
    new_context_stack: str = None

    def with_item(self, item: List[str]) -> VerifyReferenceOfByStampTaskResult:
        self.item = item
        return self

    def with_item_set(self, item_set: ItemSet) -> VerifyReferenceOfByStampTaskResult:
        self.item_set = item_set
        return self

    def with_item_model(self, item_model: ItemModel) -> VerifyReferenceOfByStampTaskResult:
        self.item_model = item_model
        return self

    def with_inventory(self, inventory: Inventory) -> VerifyReferenceOfByStampTaskResult:
        self.inventory = inventory
        return self

    def with_new_context_stack(self, new_context_stack: str) -> VerifyReferenceOfByStampTaskResult:
        self.new_context_stack = new_context_stack
        return self

    def get(self, key, default=None):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return default

    def __getitem__(self, key):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return None

    @staticmethod
    def from_dict(
        data: Dict[str, Any],
    ) -> Optional[VerifyReferenceOfByStampTaskResult]:
        if data is None:
            return None
        return VerifyReferenceOfByStampTaskResult()\
            .with_item([
                data.get('item')[i]
                for i in range(len(data.get('item')) if data.get('item') else 0)
            ])\
            .with_item_set(ItemSet.from_dict(data.get('itemSet')))\
            .with_item_model(ItemModel.from_dict(data.get('itemModel')))\
            .with_inventory(Inventory.from_dict(data.get('inventory')))\
            .with_new_context_stack(data.get('newContextStack'))

    def to_dict(self) -> Dict[str, Any]:
        return {
            "item": [
                self.item[i]
                for i in range(len(self.item) if self.item else 0)
            ],
            "itemSet": self.item_set.to_dict() if self.item_set else None,
            "itemModel": self.item_model.to_dict() if self.item_model else None,
            "inventory": self.inventory.to_dict() if self.inventory else None,
            "newContextStack": self.new_context_stack,
        }


class DescribeSimpleItemsResult(core.Gs2Result):
    items: List[SimpleItem] = None
    next_page_token: str = None

    def with_items(self, items: List[SimpleItem]) -> DescribeSimpleItemsResult:
        self.items = items
        return self

    def with_next_page_token(self, next_page_token: str) -> DescribeSimpleItemsResult:
        self.next_page_token = next_page_token
        return self

    def get(self, key, default=None):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return default

    def __getitem__(self, key):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return None

    @staticmethod
    def from_dict(
        data: Dict[str, Any],
    ) -> Optional[DescribeSimpleItemsResult]:
        if data is None:
            return None
        return DescribeSimpleItemsResult()\
            .with_items([
                SimpleItem.from_dict(data.get('items')[i])
                for i in range(len(data.get('items')) if data.get('items') else 0)
            ])\
            .with_next_page_token(data.get('nextPageToken'))

    def to_dict(self) -> Dict[str, Any]:
        return {
            "items": [
                self.items[i].to_dict() if self.items[i] else None
                for i in range(len(self.items) if self.items else 0)
            ],
            "nextPageToken": self.next_page_token,
        }


class DescribeSimpleItemsByUserIdResult(core.Gs2Result):
    items: List[SimpleItem] = None
    next_page_token: str = None

    def with_items(self, items: List[SimpleItem]) -> DescribeSimpleItemsByUserIdResult:
        self.items = items
        return self

    def with_next_page_token(self, next_page_token: str) -> DescribeSimpleItemsByUserIdResult:
        self.next_page_token = next_page_token
        return self

    def get(self, key, default=None):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return default

    def __getitem__(self, key):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return None

    @staticmethod
    def from_dict(
        data: Dict[str, Any],
    ) -> Optional[DescribeSimpleItemsByUserIdResult]:
        if data is None:
            return None
        return DescribeSimpleItemsByUserIdResult()\
            .with_items([
                SimpleItem.from_dict(data.get('items')[i])
                for i in range(len(data.get('items')) if data.get('items') else 0)
            ])\
            .with_next_page_token(data.get('nextPageToken'))

    def to_dict(self) -> Dict[str, Any]:
        return {
            "items": [
                self.items[i].to_dict() if self.items[i] else None
                for i in range(len(self.items) if self.items else 0)
            ],
            "nextPageToken": self.next_page_token,
        }


class GetSimpleItemResult(core.Gs2Result):
    item: SimpleItem = None
    item_model: SimpleItemModel = None

    def with_item(self, item: SimpleItem) -> GetSimpleItemResult:
        self.item = item
        return self

    def with_item_model(self, item_model: SimpleItemModel) -> GetSimpleItemResult:
        self.item_model = item_model
        return self

    def get(self, key, default=None):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return default

    def __getitem__(self, key):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return None

    @staticmethod
    def from_dict(
        data: Dict[str, Any],
    ) -> Optional[GetSimpleItemResult]:
        if data is None:
            return None
        return GetSimpleItemResult()\
            .with_item(SimpleItem.from_dict(data.get('item')))\
            .with_item_model(SimpleItemModel.from_dict(data.get('itemModel')))

    def to_dict(self) -> Dict[str, Any]:
        return {
            "item": self.item.to_dict() if self.item else None,
            "itemModel": self.item_model.to_dict() if self.item_model else None,
        }


class GetSimpleItemByUserIdResult(core.Gs2Result):
    item: SimpleItem = None
    item_model: SimpleItemModel = None

    def with_item(self, item: SimpleItem) -> GetSimpleItemByUserIdResult:
        self.item = item
        return self

    def with_item_model(self, item_model: SimpleItemModel) -> GetSimpleItemByUserIdResult:
        self.item_model = item_model
        return self

    def get(self, key, default=None):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return default

    def __getitem__(self, key):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return None

    @staticmethod
    def from_dict(
        data: Dict[str, Any],
    ) -> Optional[GetSimpleItemByUserIdResult]:
        if data is None:
            return None
        return GetSimpleItemByUserIdResult()\
            .with_item(SimpleItem.from_dict(data.get('item')))\
            .with_item_model(SimpleItemModel.from_dict(data.get('itemModel')))

    def to_dict(self) -> Dict[str, Any]:
        return {
            "item": self.item.to_dict() if self.item else None,
            "itemModel": self.item_model.to_dict() if self.item_model else None,
        }


class GetSimpleItemWithSignatureResult(core.Gs2Result):
    item: SimpleItem = None
    simple_item_model: SimpleItemModel = None
    body: str = None
    signature: str = None

    def with_item(self, item: SimpleItem) -> GetSimpleItemWithSignatureResult:
        self.item = item
        return self

    def with_simple_item_model(self, simple_item_model: SimpleItemModel) -> GetSimpleItemWithSignatureResult:
        self.simple_item_model = simple_item_model
        return self

    def with_body(self, body: str) -> GetSimpleItemWithSignatureResult:
        self.body = body
        return self

    def with_signature(self, signature: str) -> GetSimpleItemWithSignatureResult:
        self.signature = signature
        return self

    def get(self, key, default=None):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return default

    def __getitem__(self, key):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return None

    @staticmethod
    def from_dict(
        data: Dict[str, Any],
    ) -> Optional[GetSimpleItemWithSignatureResult]:
        if data is None:
            return None
        return GetSimpleItemWithSignatureResult()\
            .with_item(SimpleItem.from_dict(data.get('item')))\
            .with_simple_item_model(SimpleItemModel.from_dict(data.get('simpleItemModel')))\
            .with_body(data.get('body'))\
            .with_signature(data.get('signature'))

    def to_dict(self) -> Dict[str, Any]:
        return {
            "item": self.item.to_dict() if self.item else None,
            "simpleItemModel": self.simple_item_model.to_dict() if self.simple_item_model else None,
            "body": self.body,
            "signature": self.signature,
        }


class GetSimpleItemWithSignatureByUserIdResult(core.Gs2Result):
    item: SimpleItem = None
    simple_item_model: SimpleItemModel = None
    body: str = None
    signature: str = None

    def with_item(self, item: SimpleItem) -> GetSimpleItemWithSignatureByUserIdResult:
        self.item = item
        return self

    def with_simple_item_model(self, simple_item_model: SimpleItemModel) -> GetSimpleItemWithSignatureByUserIdResult:
        self.simple_item_model = simple_item_model
        return self

    def with_body(self, body: str) -> GetSimpleItemWithSignatureByUserIdResult:
        self.body = body
        return self

    def with_signature(self, signature: str) -> GetSimpleItemWithSignatureByUserIdResult:
        self.signature = signature
        return self

    def get(self, key, default=None):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return default

    def __getitem__(self, key):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return None

    @staticmethod
    def from_dict(
        data: Dict[str, Any],
    ) -> Optional[GetSimpleItemWithSignatureByUserIdResult]:
        if data is None:
            return None
        return GetSimpleItemWithSignatureByUserIdResult()\
            .with_item(SimpleItem.from_dict(data.get('item')))\
            .with_simple_item_model(SimpleItemModel.from_dict(data.get('simpleItemModel')))\
            .with_body(data.get('body'))\
            .with_signature(data.get('signature'))

    def to_dict(self) -> Dict[str, Any]:
        return {
            "item": self.item.to_dict() if self.item else None,
            "simpleItemModel": self.simple_item_model.to_dict() if self.simple_item_model else None,
            "body": self.body,
            "signature": self.signature,
        }


class AcquireSimpleItemsByUserIdResult(core.Gs2Result):
    items: List[SimpleItem] = None

    def with_items(self, items: List[SimpleItem]) -> AcquireSimpleItemsByUserIdResult:
        self.items = items
        return self

    def get(self, key, default=None):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return default

    def __getitem__(self, key):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return None

    @staticmethod
    def from_dict(
        data: Dict[str, Any],
    ) -> Optional[AcquireSimpleItemsByUserIdResult]:
        if data is None:
            return None
        return AcquireSimpleItemsByUserIdResult()\
            .with_items([
                SimpleItem.from_dict(data.get('items')[i])
                for i in range(len(data.get('items')) if data.get('items') else 0)
            ])

    def to_dict(self) -> Dict[str, Any]:
        return {
            "items": [
                self.items[i].to_dict() if self.items[i] else None
                for i in range(len(self.items) if self.items else 0)
            ],
        }


class ConsumeSimpleItemsResult(core.Gs2Result):
    items: List[SimpleItem] = None

    def with_items(self, items: List[SimpleItem]) -> ConsumeSimpleItemsResult:
        self.items = items
        return self

    def get(self, key, default=None):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return default

    def __getitem__(self, key):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return None

    @staticmethod
    def from_dict(
        data: Dict[str, Any],
    ) -> Optional[ConsumeSimpleItemsResult]:
        if data is None:
            return None
        return ConsumeSimpleItemsResult()\
            .with_items([
                SimpleItem.from_dict(data.get('items')[i])
                for i in range(len(data.get('items')) if data.get('items') else 0)
            ])

    def to_dict(self) -> Dict[str, Any]:
        return {
            "items": [
                self.items[i].to_dict() if self.items[i] else None
                for i in range(len(self.items) if self.items else 0)
            ],
        }


class ConsumeSimpleItemsByUserIdResult(core.Gs2Result):
    items: List[SimpleItem] = None

    def with_items(self, items: List[SimpleItem]) -> ConsumeSimpleItemsByUserIdResult:
        self.items = items
        return self

    def get(self, key, default=None):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return default

    def __getitem__(self, key):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return None

    @staticmethod
    def from_dict(
        data: Dict[str, Any],
    ) -> Optional[ConsumeSimpleItemsByUserIdResult]:
        if data is None:
            return None
        return ConsumeSimpleItemsByUserIdResult()\
            .with_items([
                SimpleItem.from_dict(data.get('items')[i])
                for i in range(len(data.get('items')) if data.get('items') else 0)
            ])

    def to_dict(self) -> Dict[str, Any]:
        return {
            "items": [
                self.items[i].to_dict() if self.items[i] else None
                for i in range(len(self.items) if self.items else 0)
            ],
        }


class DeleteSimpleItemsByUserIdResult(core.Gs2Result):

    def get(self, key, default=None):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return default

    def __getitem__(self, key):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return None

    @staticmethod
    def from_dict(
        data: Dict[str, Any],
    ) -> Optional[DeleteSimpleItemsByUserIdResult]:
        if data is None:
            return None
        return DeleteSimpleItemsByUserIdResult()\

    def to_dict(self) -> Dict[str, Any]:
        return {
        }


class AcquireSimpleItemsByStampSheetResult(core.Gs2Result):
    items: List[SimpleItem] = None

    def with_items(self, items: List[SimpleItem]) -> AcquireSimpleItemsByStampSheetResult:
        self.items = items
        return self

    def get(self, key, default=None):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return default

    def __getitem__(self, key):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return None

    @staticmethod
    def from_dict(
        data: Dict[str, Any],
    ) -> Optional[AcquireSimpleItemsByStampSheetResult]:
        if data is None:
            return None
        return AcquireSimpleItemsByStampSheetResult()\
            .with_items([
                SimpleItem.from_dict(data.get('items')[i])
                for i in range(len(data.get('items')) if data.get('items') else 0)
            ])

    def to_dict(self) -> Dict[str, Any]:
        return {
            "items": [
                self.items[i].to_dict() if self.items[i] else None
                for i in range(len(self.items) if self.items else 0)
            ],
        }


class ConsumeSimpleItemsByStampTaskResult(core.Gs2Result):
    items: List[SimpleItem] = None
    new_context_stack: str = None

    def with_items(self, items: List[SimpleItem]) -> ConsumeSimpleItemsByStampTaskResult:
        self.items = items
        return self

    def with_new_context_stack(self, new_context_stack: str) -> ConsumeSimpleItemsByStampTaskResult:
        self.new_context_stack = new_context_stack
        return self

    def get(self, key, default=None):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return default

    def __getitem__(self, key):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return None

    @staticmethod
    def from_dict(
        data: Dict[str, Any],
    ) -> Optional[ConsumeSimpleItemsByStampTaskResult]:
        if data is None:
            return None
        return ConsumeSimpleItemsByStampTaskResult()\
            .with_items([
                SimpleItem.from_dict(data.get('items')[i])
                for i in range(len(data.get('items')) if data.get('items') else 0)
            ])\
            .with_new_context_stack(data.get('newContextStack'))

    def to_dict(self) -> Dict[str, Any]:
        return {
            "items": [
                self.items[i].to_dict() if self.items[i] else None
                for i in range(len(self.items) if self.items else 0)
            ],
            "newContextStack": self.new_context_stack,
        }


# Copyright 2016 Game Server Services, Inc. or its affiliates. All Rights
# Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License").
# You may not use this file except in compliance with the License.
# A copy of the License is located at
#
#  http://www.apache.org/licenses/LICENSE-2.0
#
# or in the "license" file accompanying this file. This file is distributed
# on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
# express or implied. See the License for the specific language governing
# permissions and limitations under the License.

from __future__ import annotations

from .model import *


class DescribeNamespacesRequest(core.Gs2Request):

    context_stack: str = None
    page_token: str = None
    limit: int = None

    def with_page_token(self, page_token: str) -> DescribeNamespacesRequest:
        self.page_token = page_token
        return self

    def with_limit(self, limit: int) -> DescribeNamespacesRequest:
        self.limit = limit
        return self

    def get(self, key, default=None):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return default

    def __getitem__(self, key):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return None

    @staticmethod
    def from_dict(
        data: Dict[str, Any],
    ) -> Optional[DescribeNamespacesRequest]:
        if data is None:
            return None
        return DescribeNamespacesRequest()\
            .with_page_token(data.get('pageToken'))\
            .with_limit(data.get('limit'))

    def to_dict(self) -> Dict[str, Any]:
        return {
            "pageToken": self.page_token,
            "limit": self.limit,
        }


class CreateNamespaceRequest(core.Gs2Request):

    context_stack: str = None
    name: str = None
    description: str = None
    server_type: str = None
    server_spec: str = None
    create_notification: NotificationSetting = None
    log_setting: LogSetting = None

    def with_name(self, name: str) -> CreateNamespaceRequest:
        self.name = name
        return self

    def with_description(self, description: str) -> CreateNamespaceRequest:
        self.description = description
        return self

    def with_server_type(self, server_type: str) -> CreateNamespaceRequest:
        self.server_type = server_type
        return self

    def with_server_spec(self, server_spec: str) -> CreateNamespaceRequest:
        self.server_spec = server_spec
        return self

    def with_create_notification(self, create_notification: NotificationSetting) -> CreateNamespaceRequest:
        self.create_notification = create_notification
        return self

    def with_log_setting(self, log_setting: LogSetting) -> CreateNamespaceRequest:
        self.log_setting = log_setting
        return self

    def get(self, key, default=None):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return default

    def __getitem__(self, key):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return None

    @staticmethod
    def from_dict(
        data: Dict[str, Any],
    ) -> Optional[CreateNamespaceRequest]:
        if data is None:
            return None
        return CreateNamespaceRequest()\
            .with_name(data.get('name'))\
            .with_description(data.get('description'))\
            .with_server_type(data.get('serverType'))\
            .with_server_spec(data.get('serverSpec'))\
            .with_create_notification(NotificationSetting.from_dict(data.get('createNotification')))\
            .with_log_setting(LogSetting.from_dict(data.get('logSetting')))

    def to_dict(self) -> Dict[str, Any]:
        return {
            "name": self.name,
            "description": self.description,
            "serverType": self.server_type,
            "serverSpec": self.server_spec,
            "createNotification": self.create_notification.to_dict() if self.create_notification else None,
            "logSetting": self.log_setting.to_dict() if self.log_setting else None,
        }


class GetNamespaceStatusRequest(core.Gs2Request):

    context_stack: str = None
    namespace_name: str = None

    def with_namespace_name(self, namespace_name: str) -> GetNamespaceStatusRequest:
        self.namespace_name = namespace_name
        return self

    def get(self, key, default=None):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return default

    def __getitem__(self, key):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return None

    @staticmethod
    def from_dict(
        data: Dict[str, Any],
    ) -> Optional[GetNamespaceStatusRequest]:
        if data is None:
            return None
        return GetNamespaceStatusRequest()\
            .with_namespace_name(data.get('namespaceName'))

    def to_dict(self) -> Dict[str, Any]:
        return {
            "namespaceName": self.namespace_name,
        }


class GetNamespaceRequest(core.Gs2Request):

    context_stack: str = None
    namespace_name: str = None

    def with_namespace_name(self, namespace_name: str) -> GetNamespaceRequest:
        self.namespace_name = namespace_name
        return self

    def get(self, key, default=None):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return default

    def __getitem__(self, key):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return None

    @staticmethod
    def from_dict(
        data: Dict[str, Any],
    ) -> Optional[GetNamespaceRequest]:
        if data is None:
            return None
        return GetNamespaceRequest()\
            .with_namespace_name(data.get('namespaceName'))

    def to_dict(self) -> Dict[str, Any]:
        return {
            "namespaceName": self.namespace_name,
        }


class UpdateNamespaceRequest(core.Gs2Request):

    context_stack: str = None
    namespace_name: str = None
    description: str = None
    server_type: str = None
    server_spec: str = None
    create_notification: NotificationSetting = None
    log_setting: LogSetting = None

    def with_namespace_name(self, namespace_name: str) -> UpdateNamespaceRequest:
        self.namespace_name = namespace_name
        return self

    def with_description(self, description: str) -> UpdateNamespaceRequest:
        self.description = description
        return self

    def with_server_type(self, server_type: str) -> UpdateNamespaceRequest:
        self.server_type = server_type
        return self

    def with_server_spec(self, server_spec: str) -> UpdateNamespaceRequest:
        self.server_spec = server_spec
        return self

    def with_create_notification(self, create_notification: NotificationSetting) -> UpdateNamespaceRequest:
        self.create_notification = create_notification
        return self

    def with_log_setting(self, log_setting: LogSetting) -> UpdateNamespaceRequest:
        self.log_setting = log_setting
        return self

    def get(self, key, default=None):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return default

    def __getitem__(self, key):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return None

    @staticmethod
    def from_dict(
        data: Dict[str, Any],
    ) -> Optional[UpdateNamespaceRequest]:
        if data is None:
            return None
        return UpdateNamespaceRequest()\
            .with_namespace_name(data.get('namespaceName'))\
            .with_description(data.get('description'))\
            .with_server_type(data.get('serverType'))\
            .with_server_spec(data.get('serverSpec'))\
            .with_create_notification(NotificationSetting.from_dict(data.get('createNotification')))\
            .with_log_setting(LogSetting.from_dict(data.get('logSetting')))

    def to_dict(self) -> Dict[str, Any]:
        return {
            "namespaceName": self.namespace_name,
            "description": self.description,
            "serverType": self.server_type,
            "serverSpec": self.server_spec,
            "createNotification": self.create_notification.to_dict() if self.create_notification else None,
            "logSetting": self.log_setting.to_dict() if self.log_setting else None,
        }


class DeleteNamespaceRequest(core.Gs2Request):

    context_stack: str = None
    namespace_name: str = None

    def with_namespace_name(self, namespace_name: str) -> DeleteNamespaceRequest:
        self.namespace_name = namespace_name
        return self

    def get(self, key, default=None):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return default

    def __getitem__(self, key):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return None

    @staticmethod
    def from_dict(
        data: Dict[str, Any],
    ) -> Optional[DeleteNamespaceRequest]:
        if data is None:
            return None
        return DeleteNamespaceRequest()\
            .with_namespace_name(data.get('namespaceName'))

    def to_dict(self) -> Dict[str, Any]:
        return {
            "namespaceName": self.namespace_name,
        }


class NowRequest(core.Gs2Request):

    context_stack: str = None
    access_token: str = None

    def with_access_token(self, access_token: str) -> NowRequest:
        self.access_token = access_token
        return self

    def get(self, key, default=None):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return default

    def __getitem__(self, key):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return None

    @staticmethod
    def from_dict(
        data: Dict[str, Any],
    ) -> Optional[NowRequest]:
        if data is None:
            return None
        return NowRequest()\
            .with_access_token(data.get('accessToken'))

    def to_dict(self) -> Dict[str, Any]:
        return {
            "accessToken": self.access_token,
        }


class DescribeRoomsRequest(core.Gs2Request):

    context_stack: str = None
    namespace_name: str = None
    page_token: str = None
    limit: int = None

    def with_namespace_name(self, namespace_name: str) -> DescribeRoomsRequest:
        self.namespace_name = namespace_name
        return self

    def with_page_token(self, page_token: str) -> DescribeRoomsRequest:
        self.page_token = page_token
        return self

    def with_limit(self, limit: int) -> DescribeRoomsRequest:
        self.limit = limit
        return self

    def get(self, key, default=None):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return default

    def __getitem__(self, key):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return None

    @staticmethod
    def from_dict(
        data: Dict[str, Any],
    ) -> Optional[DescribeRoomsRequest]:
        if data is None:
            return None
        return DescribeRoomsRequest()\
            .with_namespace_name(data.get('namespaceName'))\
            .with_page_token(data.get('pageToken'))\
            .with_limit(data.get('limit'))

    def to_dict(self) -> Dict[str, Any]:
        return {
            "namespaceName": self.namespace_name,
            "pageToken": self.page_token,
            "limit": self.limit,
        }


class WantRoomRequest(core.Gs2Request):

    context_stack: str = None
    namespace_name: str = None
    name: str = None
    notification_user_ids: List[str] = None

    def with_namespace_name(self, namespace_name: str) -> WantRoomRequest:
        self.namespace_name = namespace_name
        return self

    def with_name(self, name: str) -> WantRoomRequest:
        self.name = name
        return self

    def with_notification_user_ids(self, notification_user_ids: List[str]) -> WantRoomRequest:
        self.notification_user_ids = notification_user_ids
        return self

    def get(self, key, default=None):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return default

    def __getitem__(self, key):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return None

    @staticmethod
    def from_dict(
        data: Dict[str, Any],
    ) -> Optional[WantRoomRequest]:
        if data is None:
            return None
        return WantRoomRequest()\
            .with_namespace_name(data.get('namespaceName'))\
            .with_name(data.get('name'))\
            .with_notification_user_ids([
                data.get('notificationUserIds')[i]
                for i in range(len(data.get('notificationUserIds')) if data.get('notificationUserIds') else 0)
            ])

    def to_dict(self) -> Dict[str, Any]:
        return {
            "namespaceName": self.namespace_name,
            "name": self.name,
            "notificationUserIds": [
                self.notification_user_ids[i]
                for i in range(len(self.notification_user_ids) if self.notification_user_ids else 0)
            ],
        }


class GetRoomRequest(core.Gs2Request):

    context_stack: str = None
    namespace_name: str = None
    room_name: str = None

    def with_namespace_name(self, namespace_name: str) -> GetRoomRequest:
        self.namespace_name = namespace_name
        return self

    def with_room_name(self, room_name: str) -> GetRoomRequest:
        self.room_name = room_name
        return self

    def get(self, key, default=None):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return default

    def __getitem__(self, key):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return None

    @staticmethod
    def from_dict(
        data: Dict[str, Any],
    ) -> Optional[GetRoomRequest]:
        if data is None:
            return None
        return GetRoomRequest()\
            .with_namespace_name(data.get('namespaceName'))\
            .with_room_name(data.get('roomName'))

    def to_dict(self) -> Dict[str, Any]:
        return {
            "namespaceName": self.namespace_name,
            "roomName": self.room_name,
        }


class DeleteRoomRequest(core.Gs2Request):

    context_stack: str = None
    namespace_name: str = None
    room_name: str = None

    def with_namespace_name(self, namespace_name: str) -> DeleteRoomRequest:
        self.namespace_name = namespace_name
        return self

    def with_room_name(self, room_name: str) -> DeleteRoomRequest:
        self.room_name = room_name
        return self

    def get(self, key, default=None):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return default

    def __getitem__(self, key):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return None

    @staticmethod
    def from_dict(
        data: Dict[str, Any],
    ) -> Optional[DeleteRoomRequest]:
        if data is None:
            return None
        return DeleteRoomRequest()\
            .with_namespace_name(data.get('namespaceName'))\
            .with_room_name(data.get('roomName'))

    def to_dict(self) -> Dict[str, Any]:
        return {
            "namespaceName": self.namespace_name,
            "roomName": self.room_name,
        }


# Copyright 2016 Game Server Services, Inc. or its affiliates. All Rights
# Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License").
# You may not use this file except in compliance with the License.
# A copy of the License is located at
#
#  http://www.apache.org/licenses/LICENSE-2.0
#
# or in the "license" file accompanying this file. This file is distributed
# on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
# express or implied. See the License for the specific language governing
# permissions and limitations under the License.

from __future__ import annotations

import re
from typing import *
from gs2 import core


class LogSetting(core.Gs2Model):
    logging_namespace_id: str = None

    def with_logging_namespace_id(self, logging_namespace_id: str) -> LogSetting:
        self.logging_namespace_id = logging_namespace_id
        return self

    def get(self, key, default=None):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return default

    def __getitem__(self, key):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return None

    @staticmethod
    def from_dict(
        data: Dict[str, Any],
    ) -> Optional[LogSetting]:
        if data is None:
            return None
        return LogSetting()\
            .with_logging_namespace_id(data.get('loggingNamespaceId'))

    def to_dict(self) -> Dict[str, Any]:
        return {
            "loggingNamespaceId": self.logging_namespace_id,
        }


class GitHubCheckoutSetting(core.Gs2Model):
    api_key_id: str = None
    repository_name: str = None
    source_path: str = None
    reference_type: str = None
    commit_hash: str = None
    branch_name: str = None
    tag_name: str = None

    def with_api_key_id(self, api_key_id: str) -> GitHubCheckoutSetting:
        self.api_key_id = api_key_id
        return self

    def with_repository_name(self, repository_name: str) -> GitHubCheckoutSetting:
        self.repository_name = repository_name
        return self

    def with_source_path(self, source_path: str) -> GitHubCheckoutSetting:
        self.source_path = source_path
        return self

    def with_reference_type(self, reference_type: str) -> GitHubCheckoutSetting:
        self.reference_type = reference_type
        return self

    def with_commit_hash(self, commit_hash: str) -> GitHubCheckoutSetting:
        self.commit_hash = commit_hash
        return self

    def with_branch_name(self, branch_name: str) -> GitHubCheckoutSetting:
        self.branch_name = branch_name
        return self

    def with_tag_name(self, tag_name: str) -> GitHubCheckoutSetting:
        self.tag_name = tag_name
        return self

    def get(self, key, default=None):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return default

    def __getitem__(self, key):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return None

    @staticmethod
    def from_dict(
        data: Dict[str, Any],
    ) -> Optional[GitHubCheckoutSetting]:
        if data is None:
            return None
        return GitHubCheckoutSetting()\
            .with_api_key_id(data.get('apiKeyId'))\
            .with_repository_name(data.get('repositoryName'))\
            .with_source_path(data.get('sourcePath'))\
            .with_reference_type(data.get('referenceType'))\
            .with_commit_hash(data.get('commitHash'))\
            .with_branch_name(data.get('branchName'))\
            .with_tag_name(data.get('tagName'))

    def to_dict(self) -> Dict[str, Any]:
        return {
            "apiKeyId": self.api_key_id,
            "repositoryName": self.repository_name,
            "sourcePath": self.source_path,
            "referenceType": self.reference_type,
            "commitHash": self.commit_hash,
            "branchName": self.branch_name,
            "tagName": self.tag_name,
        }


class ScriptSetting(core.Gs2Model):
    trigger_script_id: str = None
    done_trigger_target_type: str = None
    done_trigger_script_id: str = None
    done_trigger_queue_namespace_id: str = None

    def with_trigger_script_id(self, trigger_script_id: str) -> ScriptSetting:
        self.trigger_script_id = trigger_script_id
        return self

    def with_done_trigger_target_type(self, done_trigger_target_type: str) -> ScriptSetting:
        self.done_trigger_target_type = done_trigger_target_type
        return self

    def with_done_trigger_script_id(self, done_trigger_script_id: str) -> ScriptSetting:
        self.done_trigger_script_id = done_trigger_script_id
        return self

    def with_done_trigger_queue_namespace_id(self, done_trigger_queue_namespace_id: str) -> ScriptSetting:
        self.done_trigger_queue_namespace_id = done_trigger_queue_namespace_id
        return self

    def get(self, key, default=None):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return default

    def __getitem__(self, key):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return None

    @staticmethod
    def from_dict(
        data: Dict[str, Any],
    ) -> Optional[ScriptSetting]:
        if data is None:
            return None
        return ScriptSetting()\
            .with_trigger_script_id(data.get('triggerScriptId'))\
            .with_done_trigger_target_type(data.get('doneTriggerTargetType'))\
            .with_done_trigger_script_id(data.get('doneTriggerScriptId'))\
            .with_done_trigger_queue_namespace_id(data.get('doneTriggerQueueNamespaceId'))

    def to_dict(self) -> Dict[str, Any]:
        return {
            "triggerScriptId": self.trigger_script_id,
            "doneTriggerTargetType": self.done_trigger_target_type,
            "doneTriggerScriptId": self.done_trigger_script_id,
            "doneTriggerQueueNamespaceId": self.done_trigger_queue_namespace_id,
        }


class CurrentVersionMaster(core.Gs2Model):
    namespace_id: str = None
    settings: str = None

    def with_namespace_id(self, namespace_id: str) -> CurrentVersionMaster:
        self.namespace_id = namespace_id
        return self

    def with_settings(self, settings: str) -> CurrentVersionMaster:
        self.settings = settings
        return self

    @classmethod
    def create_grn(
        cls,
        region,
        owner_id,
        namespace_name,
    ):
        return 'grn:gs2:{region}:{ownerId}:version:{namespaceName}'.format(
            region=region,
            ownerId=owner_id,
            namespaceName=namespace_name,
        )

    @classmethod
    def get_region_from_grn(
        cls,
        grn: str,
    ) -> Optional[str]:
        match = re.search('grn:gs2:(?P<region>.+):(?P<ownerId>.+):version:(?P<namespaceName>.+)', grn)
        if match is None:
            return None
        return match.group('region')

    @classmethod
    def get_owner_id_from_grn(
        cls,
        grn: str,
    ) -> Optional[str]:
        match = re.search('grn:gs2:(?P<region>.+):(?P<ownerId>.+):version:(?P<namespaceName>.+)', grn)
        if match is None:
            return None
        return match.group('owner_id')

    @classmethod
    def get_namespace_name_from_grn(
        cls,
        grn: str,
    ) -> Optional[str]:
        match = re.search('grn:gs2:(?P<region>.+):(?P<ownerId>.+):version:(?P<namespaceName>.+)', grn)
        if match is None:
            return None
        return match.group('namespace_name')

    def get(self, key, default=None):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return default

    def __getitem__(self, key):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return None

    @staticmethod
    def from_dict(
        data: Dict[str, Any],
    ) -> Optional[CurrentVersionMaster]:
        if data is None:
            return None
        return CurrentVersionMaster()\
            .with_namespace_id(data.get('namespaceId'))\
            .with_settings(data.get('settings'))

    def to_dict(self) -> Dict[str, Any]:
        return {
            "namespaceId": self.namespace_id,
            "settings": self.settings,
        }


class SignTargetVersion(core.Gs2Model):
    region: str = None
    namespace_name: str = None
    version_name: str = None
    version: Version = None

    def with_region(self, region: str) -> SignTargetVersion:
        self.region = region
        return self

    def with_namespace_name(self, namespace_name: str) -> SignTargetVersion:
        self.namespace_name = namespace_name
        return self

    def with_version_name(self, version_name: str) -> SignTargetVersion:
        self.version_name = version_name
        return self

    def with_version(self, version: Version) -> SignTargetVersion:
        self.version = version
        return self

    def get(self, key, default=None):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return default

    def __getitem__(self, key):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return None

    @staticmethod
    def from_dict(
        data: Dict[str, Any],
    ) -> Optional[SignTargetVersion]:
        if data is None:
            return None
        return SignTargetVersion()\
            .with_region(data.get('region'))\
            .with_namespace_name(data.get('namespaceName'))\
            .with_version_name(data.get('versionName'))\
            .with_version(Version.from_dict(data.get('version')))

    def to_dict(self) -> Dict[str, Any]:
        return {
            "region": self.region,
            "namespaceName": self.namespace_name,
            "versionName": self.version_name,
            "version": self.version.to_dict() if self.version else None,
        }


class TargetVersion(core.Gs2Model):
    version_name: str = None
    version: Version = None
    body: str = None
    signature: str = None

    def with_version_name(self, version_name: str) -> TargetVersion:
        self.version_name = version_name
        return self

    def with_version(self, version: Version) -> TargetVersion:
        self.version = version
        return self

    def with_body(self, body: str) -> TargetVersion:
        self.body = body
        return self

    def with_signature(self, signature: str) -> TargetVersion:
        self.signature = signature
        return self

    def get(self, key, default=None):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return default

    def __getitem__(self, key):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return None

    @staticmethod
    def from_dict(
        data: Dict[str, Any],
    ) -> Optional[TargetVersion]:
        if data is None:
            return None
        return TargetVersion()\
            .with_version_name(data.get('versionName'))\
            .with_version(Version.from_dict(data.get('version')))\
            .with_body(data.get('body'))\
            .with_signature(data.get('signature'))

    def to_dict(self) -> Dict[str, Any]:
        return {
            "versionName": self.version_name,
            "version": self.version.to_dict() if self.version else None,
            "body": self.body,
            "signature": self.signature,
        }


class Status(core.Gs2Model):
    version_model: VersionModel = None
    current_version: Version = None

    def with_version_model(self, version_model: VersionModel) -> Status:
        self.version_model = version_model
        return self

    def with_current_version(self, current_version: Version) -> Status:
        self.current_version = current_version
        return self

    def get(self, key, default=None):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return default

    def __getitem__(self, key):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return None

    @staticmethod
    def from_dict(
        data: Dict[str, Any],
    ) -> Optional[Status]:
        if data is None:
            return None
        return Status()\
            .with_version_model(VersionModel.from_dict(data.get('versionModel')))\
            .with_current_version(Version.from_dict(data.get('currentVersion')))

    def to_dict(self) -> Dict[str, Any]:
        return {
            "versionModel": self.version_model.to_dict() if self.version_model else None,
            "currentVersion": self.current_version.to_dict() if self.current_version else None,
        }


class AcceptVersion(core.Gs2Model):
    accept_version_id: str = None
    version_name: str = None
    user_id: str = None
    version: Version = None
    created_at: int = None
    updated_at: int = None

    def with_accept_version_id(self, accept_version_id: str) -> AcceptVersion:
        self.accept_version_id = accept_version_id
        return self

    def with_version_name(self, version_name: str) -> AcceptVersion:
        self.version_name = version_name
        return self

    def with_user_id(self, user_id: str) -> AcceptVersion:
        self.user_id = user_id
        return self

    def with_version(self, version: Version) -> AcceptVersion:
        self.version = version
        return self

    def with_created_at(self, created_at: int) -> AcceptVersion:
        self.created_at = created_at
        return self

    def with_updated_at(self, updated_at: int) -> AcceptVersion:
        self.updated_at = updated_at
        return self

    @classmethod
    def create_grn(
        cls,
        region,
        owner_id,
        namespace_name,
        user_id,
        version_name,
    ):
        return 'grn:gs2:{region}:{ownerId}:version:{namespaceName}:user:{userId}:version:{versionName}:accept'.format(
            region=region,
            ownerId=owner_id,
            namespaceName=namespace_name,
            userId=user_id,
            versionName=version_name,
        )

    @classmethod
    def get_region_from_grn(
        cls,
        grn: str,
    ) -> Optional[str]:
        match = re.search('grn:gs2:(?P<region>.+):(?P<ownerId>.+):version:(?P<namespaceName>.+):user:(?P<userId>.+):version:(?P<versionName>.+):accept', grn)
        if match is None:
            return None
        return match.group('region')

    @classmethod
    def get_owner_id_from_grn(
        cls,
        grn: str,
    ) -> Optional[str]:
        match = re.search('grn:gs2:(?P<region>.+):(?P<ownerId>.+):version:(?P<namespaceName>.+):user:(?P<userId>.+):version:(?P<versionName>.+):accept', grn)
        if match is None:
            return None
        return match.group('owner_id')

    @classmethod
    def get_namespace_name_from_grn(
        cls,
        grn: str,
    ) -> Optional[str]:
        match = re.search('grn:gs2:(?P<region>.+):(?P<ownerId>.+):version:(?P<namespaceName>.+):user:(?P<userId>.+):version:(?P<versionName>.+):accept', grn)
        if match is None:
            return None
        return match.group('namespace_name')

    @classmethod
    def get_user_id_from_grn(
        cls,
        grn: str,
    ) -> Optional[str]:
        match = re.search('grn:gs2:(?P<region>.+):(?P<ownerId>.+):version:(?P<namespaceName>.+):user:(?P<userId>.+):version:(?P<versionName>.+):accept', grn)
        if match is None:
            return None
        return match.group('user_id')

    @classmethod
    def get_version_name_from_grn(
        cls,
        grn: str,
    ) -> Optional[str]:
        match = re.search('grn:gs2:(?P<region>.+):(?P<ownerId>.+):version:(?P<namespaceName>.+):user:(?P<userId>.+):version:(?P<versionName>.+):accept', grn)
        if match is None:
            return None
        return match.group('version_name')

    def get(self, key, default=None):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return default

    def __getitem__(self, key):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return None

    @staticmethod
    def from_dict(
        data: Dict[str, Any],
    ) -> Optional[AcceptVersion]:
        if data is None:
            return None
        return AcceptVersion()\
            .with_accept_version_id(data.get('acceptVersionId'))\
            .with_version_name(data.get('versionName'))\
            .with_user_id(data.get('userId'))\
            .with_version(Version.from_dict(data.get('version')))\
            .with_created_at(data.get('createdAt'))\
            .with_updated_at(data.get('updatedAt'))

    def to_dict(self) -> Dict[str, Any]:
        return {
            "acceptVersionId": self.accept_version_id,
            "versionName": self.version_name,
            "userId": self.user_id,
            "version": self.version.to_dict() if self.version else None,
            "createdAt": self.created_at,
            "updatedAt": self.updated_at,
        }


class VersionModel(core.Gs2Model):
    version_model_id: str = None
    name: str = None
    metadata: str = None
    warning_version: Version = None
    error_version: Version = None
    scope: str = None
    current_version: Version = None
    need_signature: bool = None
    signature_key_id: str = None

    def with_version_model_id(self, version_model_id: str) -> VersionModel:
        self.version_model_id = version_model_id
        return self

    def with_name(self, name: str) -> VersionModel:
        self.name = name
        return self

    def with_metadata(self, metadata: str) -> VersionModel:
        self.metadata = metadata
        return self

    def with_warning_version(self, warning_version: Version) -> VersionModel:
        self.warning_version = warning_version
        return self

    def with_error_version(self, error_version: Version) -> VersionModel:
        self.error_version = error_version
        return self

    def with_scope(self, scope: str) -> VersionModel:
        self.scope = scope
        return self

    def with_current_version(self, current_version: Version) -> VersionModel:
        self.current_version = current_version
        return self

    def with_need_signature(self, need_signature: bool) -> VersionModel:
        self.need_signature = need_signature
        return self

    def with_signature_key_id(self, signature_key_id: str) -> VersionModel:
        self.signature_key_id = signature_key_id
        return self

    @classmethod
    def create_grn(
        cls,
        region,
        owner_id,
        namespace_name,
        version_name,
    ):
        return 'grn:gs2:{region}:{ownerId}:version:{namespaceName}:model:version:{versionName}'.format(
            region=region,
            ownerId=owner_id,
            namespaceName=namespace_name,
            versionName=version_name,
        )

    @classmethod
    def get_region_from_grn(
        cls,
        grn: str,
    ) -> Optional[str]:
        match = re.search('grn:gs2:(?P<region>.+):(?P<ownerId>.+):version:(?P<namespaceName>.+):model:version:(?P<versionName>.+)', grn)
        if match is None:
            return None
        return match.group('region')

    @classmethod
    def get_owner_id_from_grn(
        cls,
        grn: str,
    ) -> Optional[str]:
        match = re.search('grn:gs2:(?P<region>.+):(?P<ownerId>.+):version:(?P<namespaceName>.+):model:version:(?P<versionName>.+)', grn)
        if match is None:
            return None
        return match.group('owner_id')

    @classmethod
    def get_namespace_name_from_grn(
        cls,
        grn: str,
    ) -> Optional[str]:
        match = re.search('grn:gs2:(?P<region>.+):(?P<ownerId>.+):version:(?P<namespaceName>.+):model:version:(?P<versionName>.+)', grn)
        if match is None:
            return None
        return match.group('namespace_name')

    @classmethod
    def get_version_name_from_grn(
        cls,
        grn: str,
    ) -> Optional[str]:
        match = re.search('grn:gs2:(?P<region>.+):(?P<ownerId>.+):version:(?P<namespaceName>.+):model:version:(?P<versionName>.+)', grn)
        if match is None:
            return None
        return match.group('version_name')

    def get(self, key, default=None):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return default

    def __getitem__(self, key):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return None

    @staticmethod
    def from_dict(
        data: Dict[str, Any],
    ) -> Optional[VersionModel]:
        if data is None:
            return None
        return VersionModel()\
            .with_version_model_id(data.get('versionModelId'))\
            .with_name(data.get('name'))\
            .with_metadata(data.get('metadata'))\
            .with_warning_version(Version.from_dict(data.get('warningVersion')))\
            .with_error_version(Version.from_dict(data.get('errorVersion')))\
            .with_scope(data.get('scope'))\
            .with_current_version(Version.from_dict(data.get('currentVersion')))\
            .with_need_signature(data.get('needSignature'))\
            .with_signature_key_id(data.get('signatureKeyId'))

    def to_dict(self) -> Dict[str, Any]:
        return {
            "versionModelId": self.version_model_id,
            "name": self.name,
            "metadata": self.metadata,
            "warningVersion": self.warning_version.to_dict() if self.warning_version else None,
            "errorVersion": self.error_version.to_dict() if self.error_version else None,
            "scope": self.scope,
            "currentVersion": self.current_version.to_dict() if self.current_version else None,
            "needSignature": self.need_signature,
            "signatureKeyId": self.signature_key_id,
        }


class Version(core.Gs2Model):
    major: int = None
    minor: int = None
    micro: int = None

    def with_major(self, major: int) -> Version:
        self.major = major
        return self

    def with_minor(self, minor: int) -> Version:
        self.minor = minor
        return self

    def with_micro(self, micro: int) -> Version:
        self.micro = micro
        return self

    def get(self, key, default=None):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return default

    def __getitem__(self, key):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return None

    @staticmethod
    def from_dict(
        data: Dict[str, Any],
    ) -> Optional[Version]:
        if data is None:
            return None
        return Version()\
            .with_major(data.get('major'))\
            .with_minor(data.get('minor'))\
            .with_micro(data.get('micro'))

    def to_dict(self) -> Dict[str, Any]:
        return {
            "major": self.major,
            "minor": self.minor,
            "micro": self.micro,
        }


class VersionModelMaster(core.Gs2Model):
    version_model_id: str = None
    name: str = None
    description: str = None
    metadata: str = None
    warning_version: Version = None
    error_version: Version = None
    scope: str = None
    current_version: Version = None
    need_signature: bool = None
    signature_key_id: str = None
    created_at: int = None
    updated_at: int = None

    def with_version_model_id(self, version_model_id: str) -> VersionModelMaster:
        self.version_model_id = version_model_id
        return self

    def with_name(self, name: str) -> VersionModelMaster:
        self.name = name
        return self

    def with_description(self, description: str) -> VersionModelMaster:
        self.description = description
        return self

    def with_metadata(self, metadata: str) -> VersionModelMaster:
        self.metadata = metadata
        return self

    def with_warning_version(self, warning_version: Version) -> VersionModelMaster:
        self.warning_version = warning_version
        return self

    def with_error_version(self, error_version: Version) -> VersionModelMaster:
        self.error_version = error_version
        return self

    def with_scope(self, scope: str) -> VersionModelMaster:
        self.scope = scope
        return self

    def with_current_version(self, current_version: Version) -> VersionModelMaster:
        self.current_version = current_version
        return self

    def with_need_signature(self, need_signature: bool) -> VersionModelMaster:
        self.need_signature = need_signature
        return self

    def with_signature_key_id(self, signature_key_id: str) -> VersionModelMaster:
        self.signature_key_id = signature_key_id
        return self

    def with_created_at(self, created_at: int) -> VersionModelMaster:
        self.created_at = created_at
        return self

    def with_updated_at(self, updated_at: int) -> VersionModelMaster:
        self.updated_at = updated_at
        return self

    @classmethod
    def create_grn(
        cls,
        region,
        owner_id,
        namespace_name,
        version_name,
    ):
        return 'grn:gs2:{region}:{ownerId}:version:{namespaceName}:model:version:{versionName}'.format(
            region=region,
            ownerId=owner_id,
            namespaceName=namespace_name,
            versionName=version_name,
        )

    @classmethod
    def get_region_from_grn(
        cls,
        grn: str,
    ) -> Optional[str]:
        match = re.search('grn:gs2:(?P<region>.+):(?P<ownerId>.+):version:(?P<namespaceName>.+):model:version:(?P<versionName>.+)', grn)
        if match is None:
            return None
        return match.group('region')

    @classmethod
    def get_owner_id_from_grn(
        cls,
        grn: str,
    ) -> Optional[str]:
        match = re.search('grn:gs2:(?P<region>.+):(?P<ownerId>.+):version:(?P<namespaceName>.+):model:version:(?P<versionName>.+)', grn)
        if match is None:
            return None
        return match.group('owner_id')

    @classmethod
    def get_namespace_name_from_grn(
        cls,
        grn: str,
    ) -> Optional[str]:
        match = re.search('grn:gs2:(?P<region>.+):(?P<ownerId>.+):version:(?P<namespaceName>.+):model:version:(?P<versionName>.+)', grn)
        if match is None:
            return None
        return match.group('namespace_name')

    @classmethod
    def get_version_name_from_grn(
        cls,
        grn: str,
    ) -> Optional[str]:
        match = re.search('grn:gs2:(?P<region>.+):(?P<ownerId>.+):version:(?P<namespaceName>.+):model:version:(?P<versionName>.+)', grn)
        if match is None:
            return None
        return match.group('version_name')

    def get(self, key, default=None):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return default

    def __getitem__(self, key):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return None

    @staticmethod
    def from_dict(
        data: Dict[str, Any],
    ) -> Optional[VersionModelMaster]:
        if data is None:
            return None
        return VersionModelMaster()\
            .with_version_model_id(data.get('versionModelId'))\
            .with_name(data.get('name'))\
            .with_description(data.get('description'))\
            .with_metadata(data.get('metadata'))\
            .with_warning_version(Version.from_dict(data.get('warningVersion')))\
            .with_error_version(Version.from_dict(data.get('errorVersion')))\
            .with_scope(data.get('scope'))\
            .with_current_version(Version.from_dict(data.get('currentVersion')))\
            .with_need_signature(data.get('needSignature'))\
            .with_signature_key_id(data.get('signatureKeyId'))\
            .with_created_at(data.get('createdAt'))\
            .with_updated_at(data.get('updatedAt'))

    def to_dict(self) -> Dict[str, Any]:
        return {
            "versionModelId": self.version_model_id,
            "name": self.name,
            "description": self.description,
            "metadata": self.metadata,
            "warningVersion": self.warning_version.to_dict() if self.warning_version else None,
            "errorVersion": self.error_version.to_dict() if self.error_version else None,
            "scope": self.scope,
            "currentVersion": self.current_version.to_dict() if self.current_version else None,
            "needSignature": self.need_signature,
            "signatureKeyId": self.signature_key_id,
            "createdAt": self.created_at,
            "updatedAt": self.updated_at,
        }


class Namespace(core.Gs2Model):
    namespace_id: str = None
    name: str = None
    description: str = None
    assume_user_id: str = None
    accept_version_script: ScriptSetting = None
    check_version_trigger_script_id: str = None
    log_setting: LogSetting = None
    created_at: int = None
    updated_at: int = None

    def with_namespace_id(self, namespace_id: str) -> Namespace:
        self.namespace_id = namespace_id
        return self

    def with_name(self, name: str) -> Namespace:
        self.name = name
        return self

    def with_description(self, description: str) -> Namespace:
        self.description = description
        return self

    def with_assume_user_id(self, assume_user_id: str) -> Namespace:
        self.assume_user_id = assume_user_id
        return self

    def with_accept_version_script(self, accept_version_script: ScriptSetting) -> Namespace:
        self.accept_version_script = accept_version_script
        return self

    def with_check_version_trigger_script_id(self, check_version_trigger_script_id: str) -> Namespace:
        self.check_version_trigger_script_id = check_version_trigger_script_id
        return self

    def with_log_setting(self, log_setting: LogSetting) -> Namespace:
        self.log_setting = log_setting
        return self

    def with_created_at(self, created_at: int) -> Namespace:
        self.created_at = created_at
        return self

    def with_updated_at(self, updated_at: int) -> Namespace:
        self.updated_at = updated_at
        return self

    @classmethod
    def create_grn(
        cls,
        region,
        owner_id,
        namespace_name,
    ):
        return 'grn:gs2:{region}:{ownerId}:version:{namespaceName}'.format(
            region=region,
            ownerId=owner_id,
            namespaceName=namespace_name,
        )

    @classmethod
    def get_region_from_grn(
        cls,
        grn: str,
    ) -> Optional[str]:
        match = re.search('grn:gs2:(?P<region>.+):(?P<ownerId>.+):version:(?P<namespaceName>.+)', grn)
        if match is None:
            return None
        return match.group('region')

    @classmethod
    def get_owner_id_from_grn(
        cls,
        grn: str,
    ) -> Optional[str]:
        match = re.search('grn:gs2:(?P<region>.+):(?P<ownerId>.+):version:(?P<namespaceName>.+)', grn)
        if match is None:
            return None
        return match.group('owner_id')

    @classmethod
    def get_namespace_name_from_grn(
        cls,
        grn: str,
    ) -> Optional[str]:
        match = re.search('grn:gs2:(?P<region>.+):(?P<ownerId>.+):version:(?P<namespaceName>.+)', grn)
        if match is None:
            return None
        return match.group('namespace_name')

    def get(self, key, default=None):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return default

    def __getitem__(self, key):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return None

    @staticmethod
    def from_dict(
        data: Dict[str, Any],
    ) -> Optional[Namespace]:
        if data is None:
            return None
        return Namespace()\
            .with_namespace_id(data.get('namespaceId'))\
            .with_name(data.get('name'))\
            .with_description(data.get('description'))\
            .with_assume_user_id(data.get('assumeUserId'))\
            .with_accept_version_script(ScriptSetting.from_dict(data.get('acceptVersionScript')))\
            .with_check_version_trigger_script_id(data.get('checkVersionTriggerScriptId'))\
            .with_log_setting(LogSetting.from_dict(data.get('logSetting')))\
            .with_created_at(data.get('createdAt'))\
            .with_updated_at(data.get('updatedAt'))

    def to_dict(self) -> Dict[str, Any]:
        return {
            "namespaceId": self.namespace_id,
            "name": self.name,
            "description": self.description,
            "assumeUserId": self.assume_user_id,
            "acceptVersionScript": self.accept_version_script.to_dict() if self.accept_version_script else None,
            "checkVersionTriggerScriptId": self.check_version_trigger_script_id,
            "logSetting": self.log_setting.to_dict() if self.log_setting else None,
            "createdAt": self.created_at,
            "updatedAt": self.updated_at,
        }